(* Content-type: application/mathematica *)

(*** Wolfram Notebook File ***)
(* http://www.wolfram.com/nb *)

(* CreatedBy='Mathematica 6.0' *)

(*CacheID: 234*)
(* Internal cache information:
NotebookFileLineBreakTest
NotebookFileLineBreakTest
NotebookDataPosition[       145,          7]
NotebookDataLength[     82306,       1798]
NotebookOptionsPosition[     78254,       1670]
NotebookOutlinePosition[     78661,       1687]
CellTagsIndexPosition[     78618,       1684]
WindowFrame->Normal*)

(* Beginning of Notebook Content *)
Notebook[{

Cell[CellGroupData[{
Cell["\<\
An incentive-compatible mechanism to break the low-skill immigration deadlock \
- data\
\>", "Title",
 CellChangeTimes->{{3.4058821453098*^9, 3.4058821707222*^9}, 
   3.4167439795167537`*^9, {3.4214886831272*^9, 3.4214886880752*^9}, 
   3.45259869765625*^9, {3.559208790770533*^9, 3.559208791612935*^9}}],

Cell["\<\
David de la Croix & Fr\[EAcute]d\[EAcute]ric Docquier \
\>", "Subtitle",
 CellChangeTimes->{{3.4058821807841997`*^9, 3.405882190425*^9}, {
   3.413028542359*^9, 3.4130285455882*^9}, 3.452598663421875*^9}],

Cell[CellGroupData[{

Cell["Special functions", "Section",
 CellChangeTimes->{{3.4058820769505997`*^9, 3.4058820790722*^9}}],

Cell["function to select elements of a list belonging to the group", "Text",
 CellChangeTimes->{{3.4058791630808*^9, 3.4058791761848*^9}}],

Cell[BoxData[
 RowBox[{
  RowBox[{"sel", "[", "x_", "]"}], ":=", 
  RowBox[{"Module", "[", 
   RowBox[{
    RowBox[{"{", "tp", "}"}], ",", 
    RowBox[{
     RowBox[{"out", "=", 
      RowBox[{"{", "}"}]}], ";", 
     RowBox[{"Do", "[", 
      RowBox[{
       RowBox[{"If", "[", 
        RowBox[{
         RowBox[{
          RowBox[{"Count", "[", 
           RowBox[{"group", ",", "j"}], "]"}], "\[Equal]", "1"}], ",", 
         RowBox[{"out", "=", 
          RowBox[{"Join", "[", 
           RowBox[{"out", ",", 
            RowBox[{"{", 
             RowBox[{"x", "[", 
              RowBox[{"[", "j", "]"}], "]"}], "}"}]}], "]"}]}]}], "]"}], ",", 
       RowBox[{"{", 
        RowBox[{"j", ",", "1", ",", "ncountry"}], "}"}]}], "]"}], ";", 
     "out"}]}], "]"}]}]], "Input",
 CellChangeTimes->{{3.4058785021868*^9, 3.4058785130288*^9}, {
  3.4058785731043997`*^9, 3.4058786114648*^9}, {3.4058786440064*^9, 
  3.4058787473564*^9}, {3.4058790691219997`*^9, 3.4058791448756*^9}, {
  3.4058792369624*^9, 3.4058792371808*^9}}],

Cell["function to give the position of a country in a group", "Text",
 CellChangeTimes->{{3.4058821090242*^9, 3.4058821308642*^9}}],

Cell[BoxData[
 RowBox[{
  RowBox[{"pos", "[", "j_", "]"}], ":=", 
  RowBox[{
   RowBox[{"Flatten", "[", 
    RowBox[{"Position", "[", 
     RowBox[{"group", ",", "j"}], "]"}], "]"}], "[", 
   RowBox[{"[", "1", "]"}], "]"}]}]], "Input",
 CellChangeTimes->{{3.4058781540727997`*^9, 3.4058781674576*^9}}]
}, Open  ]],

Cell[CellGroupData[{

Cell["The environment", "Section",
 CellChangeTimes->{{3.405773658892*^9, 3.405773661583*^9}}],

Cell[CellGroupData[{

Cell["production function", "Subsubsection",
 CellChangeTimes->{{3.405769640053*^9, 3.405769643323*^9}}],

Cell[CellGroupData[{

Cell[BoxData[{
 RowBox[{
  RowBox[{
   RowBox[{"f", "[", 
    RowBox[{"x_", ",", "\[Alpha]_"}], "]"}], "=", 
   SuperscriptBox["x", "\[Alpha]"]}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"df", "[", 
   RowBox[{"x_", ",", "\[Alpha]_"}], "]"}], "=", 
  RowBox[{"D", "[", 
   RowBox[{
    RowBox[{"f", "[", 
     RowBox[{"x", ",", "\[Alpha]"}], "]"}], ",", "x"}], "]"}]}]}], "Input",
 CellChangeTimes->CompressedData["
1:eJwdzl1IkwEUxvEXwdkK0q0y25pUo1zhxjYwUWv2kk7DChyIsw2TSWNKZQwp
N5FpzNGGoJiGsCXrA5mgNQjSKVt1NXUXqdDHhUiMhG2MXYU3G1vvcy4OP865
OPzPmwZ0D4oYhrnEDZT5f1xJ3k+yGluOrOlWL+Q5Lxs7Savl1AdonKwnX/SG
Z5ieJPtMzs7CeqnVCxPZHXLxvXkBmt48JiPKxQhcWg6SNr3+OxzUOkneWLOo
mNOYbyNvLocq4Tm2Twr3LIkqeLLRrICmslE1HLJfrKH7tnMPdih3ySqV/qCY
+vhJOB37lYGhXDQLS4+NMzzO/oEN8iFfwIeJfgNZpr91Amo/e0me0HcaNvXV
noGCq9cuwHS7UgpTs8/l8O3PswrY+mWkGX41PNFCq6X9EXSzFcPwulfigL+F
arJ8YtoFe0q6p6B4XvMK+kUrc/Dpn7SP/ngir+Ed58E76rTvB2Dmnj0Iv9U1
fIK5iuFNeFy+FqOOLfcO7ZEAKfML/kHVkdukotBVoI5sL1l92FJawhmPrpJ8
z0v3Uc6wTuSBxhsN62JXip0p2iXvatri0OH4SwbYJbOEsyPz0QL/A5kUCxk=

  "]],

Cell[BoxData[
 RowBox[{
  SuperscriptBox["x", 
   RowBox[{
    RowBox[{"-", "1"}], "+", "\[Alpha]"}]], " ", "\[Alpha]"}]], "Output",
 CellChangeTimes->{
  3.5634367710636797`*^9, 3.5635194820298357`*^9, {3.5635227591442757`*^9, 
   3.563522780560501*^9}, 3.5651956519096923`*^9, 3.565507656755362*^9, 
   3.5655199877595387`*^9, 3.5655201056700077`*^9, {3.5655917495495095`*^9, 
   3.5655917738472543`*^9}, 3.565592437229009*^9, 3.565592643307042*^9, 
   3.5655943556787953`*^9, 3.565778061261644*^9, 3.565780307312569*^9, {
   3.5657821778914413`*^9, 3.565782205461366*^9}, 3.5824553164450407`*^9, 
   3.582523394101286*^9, 3.582523686392579*^9, 3.582524114829537*^9, 
   3.582524438489792*^9, 3.582524803671558*^9, 3.5825250790631566`*^9, 
   3.5825278977188673`*^9, 3.5826036554976206`*^9, 3.582606176669752*^9, 
   3.582613425469811*^9, 3.582613582896922*^9, 3.587791666882696*^9, 
   3.587791837795856*^9, 3.587792589437893*^9, 3.5877955499119487`*^9, 
   3.5877966600959277`*^9, 3.587805591305369*^9, 3.587805949686035*^9, 
   3.5878062128049736`*^9, {3.587806308667777*^9, 3.5878063274340734`*^9}, 
   3.5878065511139517`*^9, {3.5878109499553614`*^9, 3.587810972737425*^9}, 
   3.5878130012464113`*^9, 3.5878133632014027`*^9, 3.5878157683378773`*^9, 
   3.5878158409140253`*^9, 3.587816131954932*^9, 3.5878162017742596`*^9, 
   3.5878800842893724`*^9, 3.587880177105259*^9, 3.5878802167160797`*^9, 
   3.5879821130954866`*^9, 3.5879822734763374`*^9, 3.5879825370679913`*^9, 
   3.587984271414029*^9, 3.5879848705823298`*^9, 3.5879849640388627`*^9, 
   3.5879855247782793`*^9, 3.5879855878753033`*^9, 3.5879856442211075`*^9, 
   3.5879856844895153`*^9, 3.587985813712982*^9, 3.5879858565426683`*^9, 
   3.5879859071070127`*^9, 3.5879859607183437`*^9, 3.5879873198824234`*^9, 
   3.5883313517892933`*^9, 3.589290698720138*^9, 3.589351146483987*^9, 
   3.5896311229513597`*^9, 3.5902314281409082`*^9, 3.5902951288179235`*^9, 
   3.59032225038318*^9, 3.5903223448239603`*^9, 3.5903224441349807`*^9, 
   3.5904111667683773`*^9, 3.590411723641125*^9, 3.5904117941435966`*^9, 
   3.5904118722088356`*^9, 3.5904120644845924`*^9, 3.590412225719007*^9, 
   3.591613670917142*^9, 3.5916137599516726`*^9, 3.593254221417386*^9, 
   3.593765095617293*^9, 3.5937655292614603`*^9, 3.593767791443412*^9, 
   3.593767855117882*^9, 3.593767933792961*^9, 3.5937680809403977`*^9, 
   3.593775679790702*^9, 3.5937777882873664`*^9, {3.59377881231335*^9, 
   3.593778834096593*^9}, 3.5938600893980165`*^9, 3.5938689428322077`*^9, 
   3.59386900978806*^9, 3.5939245790709057`*^9, 3.593933556161461*^9, 
   3.593935925515174*^9, 3.5939377862392707`*^9, 3.594234139064495*^9, 
   3.5942790506562767`*^9, 3.5942791547552595`*^9, 3.5942792512258286`*^9, {
   3.594539631562344*^9, 3.5945396476567497`*^9}, {3.594548611498066*^9, 
   3.5945486414524093`*^9}, 3.5951334943800545`*^9}]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell["utility function", "Subsubsection",
 CellChangeTimes->{{3.405769640053*^9, 3.405769643323*^9}, {
  3.4058592889230003`*^9, 3.40585929098*^9}}],

Cell[BoxData[
 RowBox[{
  RowBox[{
   RowBox[{"u", "[", "x_", "]"}], "=", 
   RowBox[{"Log", "[", "x", "]"}]}], ";"}]], "Input",
 CellChangeTimes->{{3.4057280866758003`*^9, 3.4057280878898*^9}, {
   3.405772081574*^9, 3.40577208273*^9}, {3.4057721446689997`*^9, 
   3.40577214583*^9}, {3.4057760379184*^9, 3.4057760420368*^9}, {
   3.4057760915668*^9, 3.4057760945620003`*^9}, {3.4057761792076*^9, 
   3.4057761794572*^9}, {3.4057763732872*^9, 3.4057763735212*^9}, {
   3.4057765067608*^9, 3.4057765081336*^9}, {3.405785298172*^9, 
   3.4057852983747997`*^9}, {3.4057853338024*^9, 3.4057853712892*^9}, {
   3.4057854072628*^9, 3.4057854591952*^9}, {3.405785492002*^9, 
   3.4057855131712*^9}, {3.4057868521504*^9, 3.4057868545684*^9}, {
   3.405786922756*^9, 3.4057869522868*^9}, {3.4057869987436*^9, 
   3.4057871022496*^9}, {3.4057871401576*^9, 3.4057871422636003`*^9}, {
   3.4057872085324*^9, 3.4057872108568*^9}, {3.405787290292*^9, 
   3.405787292866*^9}, {3.4057873248772*^9, 3.4057873377316*^9}, {
   3.4057874098816*^9, 3.40578741751*^9}, {3.4057875000808*^9, 
   3.4057875049012003`*^9}, {3.4057876919296*^9, 3.4057876995112*^9}, {
   3.4057880105439997`*^9, 3.405788120758*^9}, {3.4057881529252*^9, 
   3.4057881535648003`*^9}, {3.4057882125796003`*^9, 
   3.4057882909384003`*^9}, {3.4057883379568*^9, 3.405788357722*^9}, {
   3.4057883914024*^9, 3.4057883979544*^9}, {3.4057884471724*^9, 
   3.4057884869524*^9}, {3.4057885478236*^9, 3.4057885698508*^9}, {
   3.4057887478468*^9, 3.405788765818*^9}, {3.4057888123059998`*^9, 
   3.4057888132732*^9}, {3.4057890885508003`*^9, 3.405789090376*^9}, {
   3.4057891788124*^9, 3.4057891791244*^9}, {3.4057893062488003`*^9, 
   3.4057893097743998`*^9}, {3.4057964286106*^9, 3.4057964328226*^9}, {
   3.405859292683*^9, 3.405859338289*^9}, {3.422592381341754*^9, 
   3.4225923823245535`*^9}, {3.422778514639*^9, 3.422778516865*^9}, {
   3.4227789938199997`*^9, 3.4227789974639997`*^9}, {3.4319529962766*^9, 
   3.4319529985698*^9}, {3.498553271765625*^9, 3.49855330228125*^9}, {
   3.560680878151235*^9, 3.560680881967454*^9}, {3.587805944029608*^9, 
   3.587805946045305*^9}, {3.587806015375889*^9, 3.587806041486194*^9}, 
   3.58780620322653*^9, {3.587806301839435*^9, 3.5878063042144923`*^9}, 
   3.5878065424417925`*^9, {3.5878133320284357`*^9, 3.587813345310161*^9}, {
   3.58781571959739*^9, 3.587815750383292*^9}, {3.587815824812537*^9, 
   3.587815829015811*^9}, {3.587880164807937*^9, 3.5878801650266943`*^9}, {
   3.5878802092002087`*^9, 3.587880209668976*^9}, {3.593254203276067*^9, 
   3.5932542184797945`*^9}, {3.593765357643771*^9, 3.5937653597220078`*^9}}]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell["Data", "Section",
 CellChangeTimes->{{3.4057951568588*^9, 3.4057951592455997`*^9}, {
  3.4058769036548*^9, 3.4058769040604*^9}}],

Cell[CellGroupData[{

Cell["countries", "Subsection",
 CellChangeTimes->{{3.4058769123908*^9, 3.4058769147152*^9}}],

Cell[BoxData[
 RowBox[{
  RowBox[{"dat0", "=", 
   RowBox[{"{", 
    RowBox[{
    "\"\<Developing\>\"", ",", "\"\<Australia\>\"", ",", "\"\<Austria\>\"", 
     ",", "\"\<Bahamas\>\"", ",", "\"\<Bahrain\>\"", ",", "\"\<Belgium\>\"", 
     ",", "\"\<Brunei\>\"", ",", "\"\<Canada\>\"", ",", "\"\<Cyprus\>\"", 
     ",", "\"\<Denmark\>\"", ",", "\"\<Finland\>\"", ",", "\"\<France\>\"", 
     ",", "\"\<Germany\>\"", ",", "\"\<Greece\>\"", ",", "\"\<Hong Kong\>\"", 
     ",", "\"\<Iceland\>\"", ",", "\"\<Ireland\>\"", ",", "\"\<Israel\>\"", 
     ",", "\"\<Italy\>\"", ",", "\"\<Japan\>\"", ",", "\"\<Korea Rep\>\"", 
     ",", "\"\<Kuwait\>\"", ",", "\"\<Luxembourg\>\"", ",", "\"\<Macao\>\"", 
     ",", "\"\<Malta\>\"", ",", "\"\<Netherlands\>\"", ",", 
     "\"\<New Zealand \>\"", ",", "\"\<Norway \>\"", ",", "\"\<Portugal \>\"",
      ",", "\"\<Qatar\>\"", ",", "\"\<Saudi Arabia\>\"", ",", 
     "\"\<Singapore \>\"", ",", "\"\<Slovenia \>\"", ",", "\"\<Spain\>\"", 
     ",", "\"\<Sweden\>\"", ",", "\"\<Switzerland\>\"", ",", "\"\<UAE\>\"", 
     ",", "\"\<UK\>\"", ",", "\"\<USA\>\""}], "}"}]}], ";"}]], "Input",
 CellChangeTimes->{{3.4058812336614*^9, 3.4058813795369997`*^9}, {
   3.4058825908694*^9, 3.405882591743*^9}, {3.4058836089462*^9, 
   3.4058836248894*^9}, {3.4167333280009537`*^9, 3.4167333544897537`*^9}, {
   3.4214102206758003`*^9, 3.4214103386274*^9}, {3.4316893374229803`*^9, 
   3.4316893447237797`*^9}, 3.45077992425*^9}],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"ncountry", "=", 
  RowBox[{"Length", "[", "dat0", "]"}]}]], "Input",
 CellChangeTimes->{{3.421410311967*^9, 3.4214103179418*^9}, 
   3.4214103511074*^9}],

Cell[BoxData["39"], "Output",
 CellChangeTimes->{
  3.56343677107668*^9, 3.563519482069838*^9, {3.5635227591622767`*^9, 
   3.563522780579502*^9}, 3.565195651940892*^9, 3.5655076567866125`*^9, 
   3.565519987775166*^9, 3.5655201057012587`*^9, {3.565591749565138*^9, 
   3.5655917738628798`*^9}, 3.5655924372446346`*^9, 3.5655926433382955`*^9, 
   3.5655943557100463`*^9, 3.5657780612772694`*^9, 3.5657803073281927`*^9, {
   3.5657821779070683`*^9, 3.5657822054926205`*^9}, 3.5824553164763184`*^9, 
   3.582523394132535*^9, 3.58252368642383*^9, 3.5825241148451333`*^9, 
   3.582524438521044*^9, 3.5825248036871777`*^9, 3.58252507907878*^9, 
   3.582527897750094*^9, 3.5826036555132465`*^9, 3.5826061766897726`*^9, 
   3.5826134254854355`*^9, 3.5826135829125495`*^9, 3.5877916669764504`*^9, 
   3.587791837889603*^9, 3.58779258951602*^9, 3.5877955500369544`*^9, 
   3.5877966602903233`*^9, 3.587805591524127*^9, 3.587805949701661*^9, 
   3.5878062129143515`*^9, {3.5878063087302804`*^9, 3.5878063275278273`*^9}, 
   3.587806551176454*^9, {3.587810950033489*^9, 3.587810972799927*^9}, 
   3.5878130013089123`*^9, 3.5878133632639017`*^9, 3.5878157684578876`*^9, 
   3.587815841039029*^9, 3.58781613203306*^9, 3.5878162018523874`*^9, 
   3.5878800843362494`*^9, 3.5878801771677628`*^9, 3.5878802167942085`*^9, 
   3.5879821131423626`*^9, 3.587982273523214*^9, 3.587982537099244*^9, 
   3.587984271460905*^9, 3.587984870597955*^9, 3.5879849640544896`*^9, 
   3.5879855247939043`*^9, 3.587985587890928*^9, 3.587985644236732*^9, 
   3.5879856844895153`*^9, 3.5879858137286053`*^9, 3.5879858565582952`*^9, 
   3.587985907122638*^9, 3.5879859607339697`*^9, 3.5879873198980465`*^9, 
   3.58833135180492*^9, 3.5892906987357635`*^9, 3.589351146499611*^9, 
   3.589631122966984*^9, 3.590231428156534*^9, 3.5902951288491716`*^9, 
   3.590322250398774*^9, 3.5903223448708367`*^9, 3.590322444197482*^9, 
   3.5904111667996273`*^9, 3.5904117236567497`*^9, 3.5904117941592216`*^9, 
   3.5904118722244616`*^9, 3.5904120645158424`*^9, 3.5904122257815104`*^9, 
   3.591613670948393*^9, 3.5916137599829235`*^9, 3.593254221433011*^9, 
   3.5937650956329193`*^9, 3.5937655292927103`*^9, 3.5937677914590373`*^9, 
   3.5937678551335077`*^9, 3.5937679338085885`*^9, 3.593768080956025*^9, 
   3.593775679821951*^9, 3.5937777883029923`*^9, {3.5937788123289766`*^9, 
   3.5937788341122174`*^9}, 3.593860089429264*^9, 3.5938689428634605`*^9, 
   3.5938690098036857`*^9, 3.5939245791021566`*^9, 3.5939335561770887`*^9, 
   3.5939359255308*^9, 3.593937786254896*^9, 3.594234139095695*^9, 
   3.5942790507030764`*^9, 3.594279154786459*^9, 3.5942792512570286`*^9, {
   3.5945396315779686`*^9, 3.5945396476880007`*^9}, {3.594548611513691*^9, 
   3.5945486414680347`*^9}, 3.5951334943956814`*^9}]
}, Open  ]],

Cell["index of the US - for graphs", "Text",
 CellChangeTimes->{{3.4058819983733997`*^9, 3.4058820096521997`*^9}}],

Cell[BoxData[
 RowBox[{
  RowBox[{"nusa", "=", "39"}], ";"}]], "Input",
 CellChangeTimes->{{3.4058804712586*^9, 3.405880474519*^9}, {
  3.4058812194342003`*^9, 3.4058812197306004`*^9}, {3.4214103639462*^9, 
  3.421410365241*^9}}],

Cell["possible groups", "Text",
 CellChangeTimes->{{3.4058817829686003`*^9, 3.4058817849966*^9}}],

Cell[BoxData[{
 RowBox[{
  RowBox[{"OECD", "=", 
   RowBox[{"{", 
    RowBox[{
    "2", ",", "3", ",", "6", ",", "8", ",", "10", ",", "11", ",", "12", ",", 
     " ", "13", ",", "14", ",", "16", ",", "17", ",", "19", ",", "20", ",", 
     "21", ",", "23", ",", "26", ",", "27", ",", "28", ",", "29", ",", "34", 
     ",", "35", ",", "36", ",", "38", ",", "39"}], "}"}]}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"HIGHINCOME", "=", 
   RowBox[{"{", 
    RowBox[{
    "2", ",", "3", ",", "4", ",", "5", ",", "6", ",", "7", ",", "8", ",", "9",
      ",", "10", ",", "11", ",", "12", ",", "13", ",", "14", ",", "15", ",", 
     "16", ",", "17", ",", "18", ",", "19", ",", "20", ",", "21", ",", "22", 
     ",", "23", ",", "24", ",", "25", ",", "26", ",", "27", ",", "28", ",", 
     "29", ",", "30", ",", "31", ",", "32", ",", "33", ",", "34", ",", "35", 
     ",", "36", ",", "37", ",", "38", ",", "39"}], "}"}]}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"G7", "=", 
   RowBox[{"{", 
    RowBox[{
    "8", ",", "12", ",", "13", ",", "19", ",", "20", ",", "38", ",", "39"}], 
    "}"}]}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"ALL", "=", 
   RowBox[{"Table", "[", 
    RowBox[{"j", ",", 
     RowBox[{"{", 
      RowBox[{"j", ",", "1", ",", "ncountry"}], "}"}]}], "]"}]}], 
  ";"}]}], "Input",
 CellChangeTimes->{{3.4058769251204*^9, 3.4058769685976*^9}, {
   3.405881515881*^9, 3.4058816090598*^9}, {3.4058817323934*^9, 
   3.405881777649*^9}, {3.4214103734154*^9, 3.4214105602722*^9}, {
   3.4214106627798*^9, 3.4214107475472*^9}, {3.4214107782792*^9, 
   3.4214108099472*^9}, {3.4316893535065804`*^9, 3.43168937283498*^9}, {
   3.43168941242778*^9, 3.43168941263058*^9}, {3.450779933546875*^9, 
   3.450779934015625*^9}, 3.4511283666875*^9, {3.453118062234375*^9, 
   3.453118084203125*^9}, {3.453118405703125*^9, 3.45311841528125*^9}}],

Cell[BoxData[
 RowBox[{"Do", "[", 
  RowBox[{
   RowBox[{
    RowBox[{"id", "[", "j", "]"}], "=", 
    RowBox[{"dat0", "[", 
     RowBox[{"[", "j", "]"}], "]"}]}], ",", 
   RowBox[{"{", 
    RowBox[{"j", ",", "ALL"}], "}"}]}], "]"}]], "Input",
 CellChangeTimes->{{3.4058772345308*^9, 3.4058772357944*^9}, {
  3.4058777090516*^9, 3.4058777104244003`*^9}, {3.4223317563157444`*^9, 
  3.4223317566745443`*^9}, {3.5599726465533905`*^9, 3.5599726469745913`*^9}}],

Cell[CellGroupData[{

Cell["Data", "Subsubsection",
 CellChangeTimes->{{3.405769621692*^9, 3.40576963083*^9}, {3.4057955560472*^9,
   3.4057955612108*^9}}],

Cell["native working age population (in thousands) ", "Text",
 CellChangeTimes->{{3.4057959292702*^9, 3.4057959533566*^9}, 
   3.405796063087*^9, {3.4058574890039997`*^9, 3.405857491958*^9}, {
   3.422329717302144*^9, 3.4223297184409447`*^9}, {3.422330561636544*^9, 
   3.4223305625881443`*^9}}],

Cell[BoxData[{
 RowBox[{
  RowBox[{"dat1", "=", 
   RowBox[{"{", 
    RowBox[{
    "2490589", ",", "11510", ",", "5266", ",", "144", ",", "235", ",", "6882",
      ",", "118", ",", "18696", ",", "465", ",", "3600", ",", "3524", ",", 
     "37451", ",", "55516", ",", "7126", ",", "2931", ",", "169", ",", "2264",
      ",", "2349", ",", "41712", ",", "91839", ",", "42217", ",", "782", ",", 
     "285", ",", "270", ",", "252", ",", "10335", ",", "2275", ",", "2928", 
     ",", "6581", ",", "104", ",", "7241", ",", "2278", ",", "1348", ",", 
     "27821", ",", "5809", ",", "4675", ",", "617", ",", "38515", ",", 
     "167564"}], "}"}]}], ";"}], "\[IndentingNewLine]", 
 RowBox[{"Do", "[", 
  RowBox[{
   RowBox[{
    RowBox[{"n", "[", "j", "]"}], "=", 
    RowBox[{"dat1", "[", 
     RowBox[{"[", "j", "]"}], "]"}]}], ",", 
   RowBox[{"{", 
    RowBox[{"j", ",", "ALL"}], "}"}]}], "]"}]}], "Input",
 CellChangeTimes->{
  3.4214110621196003`*^9, {3.4214111035376*^9, 3.4214111308532*^9}, {
   3.4223297221537447`*^9, 3.4223297700301447`*^9}, {3.4223305131829443`*^9, 
   3.4223305584853444`*^9}, 3.4223317639909444`*^9, {3.43168940178858*^9, 
   3.43168940522058*^9}, {3.4320143211717997`*^9, 3.4320143227942*^9}, {
   3.4320144238666*^9, 3.4320144241006002`*^9}, 3.4507799419375*^9, {
   3.5599726494081955`*^9, 3.559972649751396*^9}, {3.587984225318596*^9, 
   3.5879842263967595`*^9}, {3.5879848673634653`*^9, 3.587984867754126*^9}, {
   3.5879849440537853`*^9, 3.5879849444913006`*^9}, {3.5879858061189814`*^9, 
   3.5879858063533425`*^9}, {3.587985851495635*^9, 3.5879858526519284`*^9}, {
   3.587985944874022*^9, 3.5879859453115373`*^9}, {3.5879872560832253`*^9, 
   3.587987256520743*^9}, {3.5916136144775624`*^9, 3.5916136146963196`*^9}}],

Cell["share of high school graduates in population", "Text",
 CellChangeTimes->{{3.559972398762555*^9, 3.559972403645364*^9}, {
  3.56550749699965*^9, 3.5655074985153522`*^9}}],

Cell[BoxData[
 RowBox[{
  RowBox[{"dat6", "=", 
   RowBox[{"{", 
    RowBox[{
    "0.03300", ",", "0.18600", ",", "0.07700", ",", "0.08000", ",", "0.04500",
      ",", "0.17900", ",", "0.04500", ",", "0.19600", ",", "0.19600", ",", 
     "0.11200", ",", "0.07100", ",", "0.08800", ",", "0.13200", ",", 
     "0.14100", ",", "0.07200", ",", "0.11600", ",", "0.16800", ",", 
     "0.24400", ",", "0.05700", ",", "0.19000", ",", "0.14800", ",", 
     "0.06600", ",", "0.11000", ",", "0.07200", ",", "0.06000", ",", 
     "0.14900", ",", "0.20800", ",", "0.12200", ",", "0.03900", ",", 
     "0.10500", ",", "0.08700", ",", "0.07800", ",", "0.08100", ",", 
     "0.12100", ",", "0.15500", ",", "0.12800", ",", "0.07900", ",", 
     "0.09800", ",", "0.30600"}], "}"}]}], ";"}]], "Input",
 CellChangeTimes->{{3.5599723747697134`*^9, 3.559972457559059*^9}, {
   3.5613692260719476`*^9, 3.5613692271840115`*^9}, {3.561369273882682*^9, 
   3.5613693214324017`*^9}, 3.561989443470257*^9, {3.565780295015238*^9, 
   3.5657802959840236`*^9}, {3.593937728377565*^9, 3.5939377296900926`*^9}}],

Cell["migrant to native ratio", "Text",
 CellChangeTimes->{{3.4057960781878*^9, 3.4057960823842*^9}}],

Cell[BoxData[
 RowBox[{
  RowBox[{"dat2", "=", 
   RowBox[{"{", 
    RowBox[{
    "0", ",", "0.087820444", ",", "0.101765695", ",", "0.080532054", ",", 
     "0.548834028", ",", "0.051035827", ",", "0.420316031", ",", 
     "0.112786243", ",", "0.034193092", ",", "0.041053453", ",", 
     "0.015778013", ",", "0.079221847", ",", "0.085608955", ",", "0.087514", 
     ",", "0.601916181", ",", "0.027243817", ",", "0.019972776", ",", 
     "0.403890876", ",", "0.021934306", ",", "0.00542699", ",", "0.001700981",
      ",", "0.670325617", ",", "0.062709617", ",", "0.05603575", ",", 
     "0.003143527", ",", "0.074920723", ",", "0.054811132", ",", 
     "0.041870809", ",", "0.046750793", ",", "2.371723866", ",", "0.29158633",
      ",", "0.159260569", ",", "0.025370976", ",", "0.036588604", ",", 
     "0.070617469", ",", "0.11237793", ",", "1.696523493", ",", "0.04771965", 
     ",", "0.095486952"}], "}"}]}], ";"}]], "Input",
 CellChangeTimes->{{3.4057960944898*^9, 3.4057961642998*^9}, {
   3.4058037209370003`*^9, 3.4058037293297997`*^9}, {3.4058043514578*^9, 
   3.4058043782742*^9}, {3.4058045752242002`*^9, 3.4058046048486*^9}, {
   3.4058048657586*^9, 3.4058048718269997`*^9}, {3.4058064486906*^9, 
   3.4058065229466*^9}, {3.405861167901*^9, 3.405861183924*^9}, {
   3.4058771623028*^9, 3.4058771626616*^9}, {3.4058777190668*^9, 
   3.4058777194568*^9}, {3.405883299645*^9, 3.4058833593462*^9}, 
   3.4136142663056045`*^9, {3.4214111879804*^9, 3.4214111952967997`*^9}, 
   3.4223317658161445`*^9, {3.43168941684258*^9, 3.43168941918258*^9}, 
   3.45077994565625*^9, {3.5599724766066923`*^9, 3.5599725154819603`*^9}, {
   3.5599726521382003`*^9, 3.559972652512601*^9}, {3.5655075092969675`*^9, 
   3.56550753564168*^9}}],

Cell["total number of migrants", "Text",
 CellChangeTimes->{{3.4057960944898*^9, 3.4057961642998*^9}, {
   3.4058037209370003`*^9, 3.4058037293297997`*^9}, {3.4058043514578*^9, 
   3.4058043782742*^9}, {3.4058045752242002`*^9, 3.4058046048486*^9}, {
   3.4058048657586*^9, 3.4058048718269997`*^9}, {3.4058064486906*^9, 
   3.4058065229466*^9}, {3.405861167901*^9, 3.405861183924*^9}, {
   3.4058771623028*^9, 3.4058771626616*^9}, {3.4058777190668*^9, 
   3.4058777194568*^9}, {3.405883299645*^9, 3.4058833593462*^9}, 
   3.4136142663056045`*^9, {3.4214111879804*^9, 3.4214111952967997`*^9}, 
   3.4223317658161445`*^9, {3.43168941684258*^9, 3.43168941918258*^9}, 
   3.45077994565625*^9, {3.5599724766066923`*^9, 3.5599725154819603`*^9}, {
   3.5599726521382003`*^9, 3.559972652512601*^9}, {3.5655075092969675`*^9, 
   3.5655075399543343`*^9}}],

Cell[BoxData[{
 RowBox[{"Do", "[", 
  RowBox[{
   RowBox[{
    RowBox[{
     RowBox[{"mn", "[", "j", "]"}], "=", 
     RowBox[{"dat2", "[", 
      RowBox[{"[", "j", "]"}], "]"}]}], ";", 
    RowBox[{
     RowBox[{"mm", "[", "j", "]"}], "=", 
     RowBox[{
      RowBox[{"n", "[", "j", "]"}], " ", 
      RowBox[{"mn", "[", "j", "]"}]}]}]}], ",", 
   RowBox[{"{", 
    RowBox[{"j", ",", "ALL"}], "}"}]}], "]"}], "\[IndentingNewLine]", 
 RowBox[{"Do", "[", 
  RowBox[{
   RowBox[{
    RowBox[{
     RowBox[{"nH", "[", "j", "]"}], "=", 
     RowBox[{
      RowBox[{"(", 
       RowBox[{
        RowBox[{"n", "[", "j", "]"}], "+", 
        RowBox[{"mm", "[", "j", "]"}]}], ")"}], 
      RowBox[{"dat6", "[", 
       RowBox[{"[", "j", "]"}], "]"}]}]}], ";", 
    RowBox[{
     RowBox[{"nL", "[", "j", "]"}], "=", 
     RowBox[{
      RowBox[{"n", "[", "j", "]"}], "-", 
      RowBox[{"nH", "[", "j", "]"}]}]}]}], ",", 
   RowBox[{"{", 
    RowBox[{"j", ",", "ALL"}], "}"}]}], "]"}]}], "Input",
 CellChangeTimes->{{3.4057960944898*^9, 3.4057961642998*^9}, {
   3.4058037209370003`*^9, 3.4058037293297997`*^9}, {3.4058043514578*^9, 
   3.4058043782742*^9}, {3.4058045752242002`*^9, 3.4058046048486*^9}, {
   3.4058048657586*^9, 3.4058048718269997`*^9}, {3.4058064486906*^9, 
   3.4058065229466*^9}, {3.405861167901*^9, 3.405861183924*^9}, {
   3.4058771623028*^9, 3.4058771626616*^9}, {3.4058777190668*^9, 
   3.4058777194568*^9}, {3.405883299645*^9, 3.4058833593462*^9}, 
   3.4136142663056045`*^9, {3.4214111879804*^9, 3.4214111952967997`*^9}, 
   3.4223317658161445`*^9, {3.43168941684258*^9, 3.43168941918258*^9}, 
   3.45077994565625*^9, {3.5599724766066923`*^9, 3.5599725154819603`*^9}, {
   3.5599726521382003`*^9, 3.559972652512601*^9}, {3.5655075092969675`*^9, 
   3.5655075495640326`*^9}}],

Cell["total gnp in millions usd", "Text",
 CellChangeTimes->{{3.4057961743462*^9, 3.4057961812882*^9}, {
  3.4058028093682003`*^9, 3.4058028181042*^9}, {3.4223297789533443`*^9, 
  3.4223297793277445`*^9}}],

Cell[BoxData[{
 RowBox[{
  RowBox[{"dat3", "=", 
   RowBox[{"{", 
    RowBox[{
    "17601479", ",", "449904", ",", "202039", ",", "4612", ",", "9995", ",", 
     "243451", ",", "6435", ",", "777173", ",", "14752", ",", "143881", ",", 
     "116241", ",", "1310046", ",", "1959456", ",", "167766", ",", "154995", 
     ",", "7589", ",", "100899", ",", "118363", ",", "1325246", ",", 
     "3065754", ",", "914707", ",", "40967", ",", "20241", ",", "9151", ",", 
     "4933", ",", "407707", ",", "65870", ",", "125173", ",", "166149", ",", 
     "8730", ",", "285253", ",", "84160", ",", "30513", ",", "755696", ",", 
     "196551", ",", "192476", ",", "57895", ",", "1309938", ",", "9176050"}], 
    "}"}]}], ";"}], "\[IndentingNewLine]", 
 RowBox[{"Do", "[", 
  RowBox[{
   RowBox[{
    RowBox[{"y", "[", "j", "]"}], "=", 
    RowBox[{"dat3", "[", 
     RowBox[{"[", "j", "]"}], "]"}]}], ",", 
   RowBox[{"{", 
    RowBox[{"j", ",", "ALL"}], "}"}]}], "]"}]}], "Input",
 CellChangeTimes->{{3.4057961836282*^9, 3.4057961931754*^9}, {
   3.4057962563398*^9, 3.4057962987094*^9}, {3.4058037323406*^9, 
   3.4058037410922003`*^9}, {3.4058043804894*^9, 3.4058043949662*^9}, {
   3.4058046077502003`*^9, 3.4058046365322*^9}, {3.4058048751029997`*^9, 
   3.4058048847438*^9}, {3.4058065277202*^9, 3.4058066004006*^9}, {
   3.4058611932790003`*^9, 3.405861208094*^9}, {3.4058772613316*^9, 
   3.4058772617684*^9}, {3.4058777224988003`*^9, 3.4058777229824*^9}, {
   3.4058833666938*^9, 3.4058834544906*^9}, {3.4214112705668*^9, 
   3.4214112750908003`*^9}, {3.4214113959284*^9, 3.4214114004056*^9}, 
   3.4223317776721444`*^9, {3.43168942428378*^9, 3.43168943495418*^9}, {
   3.4320141692902*^9, 3.4320141710842*^9}, 3.4320142819846*^9, 
   3.45077994946875*^9, {3.5599726546966047`*^9, 3.559972655008606*^9}, {
   3.587984237584671*^9, 3.5879842388972416`*^9}, {3.587984959726207*^9, 
   3.587984960132471*^9}, {3.587985575077985*^9, 3.5879855772967973`*^9}, {
   3.587985641220998*^9, 3.5879856729734783`*^9}, {3.587985810275378*^9, 
   3.587985810572242*^9}, {3.587985903419405*^9, 3.587985904419424*^9}, {
   3.587985951124245*^9, 3.587985956421338*^9}, {3.587987261895957*^9, 
   3.5879872712712994`*^9}}],

Cell["\<\
aid in dollars per native. transformed into per high skilled.\
\>", "Text",
 CellChangeTimes->{{3.422329923222144*^9, 3.422329926934944*^9}, {
   3.4223416564296*^9, 3.4223416923396*^9}, {3.561984451039285*^9, 
   3.5619844574196963`*^9}, 3.565782020854322*^9, {3.5657820592463894`*^9, 
   3.5657820653403683`*^9}}],

Cell[BoxData[{
 RowBox[{
  RowBox[{"dat4", "=", 
   RowBox[{"{", 
    RowBox[{
    "0", ",", "112.3220697", ",", "125.2788177", ",", "105.9932842", ",", 
     "205.9241415", ",", "152.3545018", ",", "158.8332763", ",", 
     "109.1546846", ",", "113.7523893", ",", "490.7497375", ",", 
     "128.0215152", ",", "145.0073319", ",", "116.9744112", ",", 
     "50.73112622", ",", "201.5515999", ",", "27.97422197", ",", 
     "142.6385831", ",", "167.835474", ",", "55.61720974", ",", "91.415088", 
     ",", "12.28296693", ",", "282.3246391", ",", "528.9491708", ",", 
     "29.8986076", ",", "67.86016377", ",", "396.3996298", ",", "84.30092775",
      ",", "372.1931008", ",", "76.10678911", ",", "466.4320964", ",", 
     "194.2910064", ",", "132.0038392", ",", "90.03678874", ",", 
     "81.22559636", ",", "302.6064823", ",", "186.8726721", ",", 
     "459.3754826", ",", "114.5548218", ",", "63.20635011"}], "}"}]}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{"Do", "[", 
  RowBox[{
   RowBox[{
    RowBox[{"aid", "[", "j", "]"}], "=", 
    RowBox[{
     RowBox[{
      RowBox[{"dat4", "[", 
       RowBox[{"[", "j", "]"}], "]"}], "/", "1000"}], 
     RowBox[{
      RowBox[{"(", 
       RowBox[{
        RowBox[{"nH", "[", "j", "]"}], "+", 
        RowBox[{"nL", "[", "j", "]"}]}], ")"}], "/", 
      RowBox[{"nH", "[", "j", "]"}]}]}]}], ",", 
   RowBox[{"{", 
    RowBox[{"j", ",", "ALL"}], "}"}]}], "]"}]}], "Input",
 CellChangeTimes->{{3.422329935592944*^9, 3.422329938135744*^9}, {
   3.4223299768861446`*^9, 3.422330019115344*^9}, {3.422330067646944*^9, 
   3.4223300784577446`*^9}, {3.4223305841317444`*^9, 3.4223306135377445`*^9}, 
   3.4223317720249443`*^9, {3.422334087786744*^9, 3.4223340922639446`*^9}, {
   3.43168943997738*^9, 3.43168944206778*^9}, 3.450779952359375*^9, {
   3.559972659454613*^9, 3.559972659875814*^9}, {3.5619844433016715`*^9, 
   3.5619844494324827`*^9}, {3.565782119826762*^9, 3.5657821276708064`*^9}}],

Cell["gini coef after redis / gini before", "Text",
 CellChangeTimes->{{3.5599914600092955`*^9, 3.559991461913404*^9}, {
  3.560685571939705*^9, 3.560685576996994*^9}}],

Cell[BoxData[{
 RowBox[{
  RowBox[{"dat5", "=", 
   RowBox[{"{", 
    RowBox[{
    "0.829", ",", "0.712", ",", "0.703", ",", "0.815", ",", "0.828", ",", 
     "0.613", ",", "0.810", ",", "0.781", ",", "0.765", ",", "0.733", ",", 
     "0.791", ",", "0.690", ",", "0.692", ",", "0.751", ",", "0.821", ",", 
     "0.746", ",", "0.625", ",", "0.696", ",", "0.850", ",", "0.776", ",", 
     "0.802", ",", "0.802", ",", "0.703", ",", "0.824", ",", "0.745", ",", 
     "0.705", ",", "0.761", ",", "0.709", ",", "0.725", ",", "0.827", ",", 
     "0.794", ",", "0.833", ",", "0.719", ",", "0.809", ",", "0.629", ",", 
     "0.871", ",", "0.835", ",", "0.757", ",", "0.829"}], "}"}]}], 
  ";"}], "\n", 
 RowBox[{"Do", "[", 
  RowBox[{
   RowBox[{
    RowBox[{"ginc", "[", "j", "]"}], "=", 
    RowBox[{"dat5", "[", 
     RowBox[{"[", "j", "]"}], "]"}]}], ",", 
   RowBox[{"{", 
    RowBox[{"j", ",", "ALL"}], "}"}]}], "]"}]}], "Input",
 CellChangeTimes->{{3.559991483473637*^9, 3.5599915976271667`*^9}, {
   3.5605335286928396`*^9, 3.5605335688941107`*^9}, 3.5939377358153467`*^9, 
   3.594279044307065*^9, {3.594279137626429*^9, 3.5942791378916297`*^9}, {
   3.5942792093553553`*^9, 3.5942792145657644`*^9}}],

Cell["share of redistribution in gdp", "Text",
 CellChangeTimes->{{3.5602406544355793`*^9, 3.5602406624227934`*^9}}],

Cell[BoxData[
 RowBox[{
  RowBox[{"dat7", "=", 
   RowBox[{"{", 
    RowBox[{
    "0", ",", "0.1196", ",", "0.2214", ",", "0.0680", ",", "0.0514", ",", 
     "0.2236", ",", "0.0760", ",", "0.1570", ",", "0.1360", ",", "0.1806", 
     ",", "0.1917", ",", "0.2397", ",", "0.1947", ",", "0.1557", ",", 
     "0.0604", ",", "0.1631", ",", "0.1398", ",", "0.1593", ",", "0.1892", 
     ",", "0.1223", ",", "0.0868", ",", "0.0868", ",", "0.1755", ",", 
     "0.0561", ",", "0.1638", ",", "0.1937", ",", "0.1420", ",", "0.2006", 
     ",", "0.1905", ",", "0.0529", ",", "0.0972", ",", "0.0443", ",", 
     "0.1988", ",", "0.1666", ",", "0.2166", ",", "0.1624", ",", "0.0408", 
     ",", "0.1667", ",", "0.1663"}], "}"}]}], ";"}]], "Input",
 CellChangeTimes->{{3.5602406652931986`*^9, 3.5602407364293237`*^9}, {
   3.5606678737781878`*^9, 3.5606678741837883`*^9}, 3.5622370776728487`*^9, 
   3.563078275175564*^9}],

Cell["\<\
remittances_as _a _share _of _ income of low skilled migrants\
\>", "Text",
 CellChangeTimes->{{3.467520188359375*^9, 3.467520200625*^9}, 
   3.467520381125*^9, {3.467520570640625*^9, 3.46752057134375*^9}, {
   3.5613973607324753`*^9, 3.561397377468105*^9}, {3.5619898960738516`*^9, 
   3.561989990670218*^9}, {3.562411268762311*^9, 3.562411278846888*^9}}],

Cell[BoxData[
 RowBox[{
  RowBox[{"\[Delta]", "=", "0.0296"}], ";"}]], "Input",
 CellChangeTimes->{{3.467520188359375*^9, 3.467520200625*^9}, 
   3.467520381125*^9, {3.467520570640625*^9, 3.46752057134375*^9}, {
   3.5613973607324753`*^9, 3.561397377468105*^9}, {3.5619898960738516`*^9, 
   3.561989974352589*^9}, 3.5619900071438465`*^9, {3.5622370445071898`*^9, 
   3.5622370467691936`*^9}, {3.562411297859976*^9, 3.5624113074965267`*^9}}],

Cell["Downgrading of migrants skills", "Text",
 CellChangeTimes->{{3.5622645718443365`*^9, 3.5622645773306503`*^9}}],

Cell[BoxData[
 RowBox[{
  RowBox[{"dat8", "=", 
   RowBox[{"{", 
    RowBox[{
    "1", ",", "0.767485387", ",", "0.707541305", ",", "0.865195326", ",", 
     "0.895640591", ",", "0.718919208", ",", "0.821641801", ",", 
     "0.741359164", ",", "0.864625817", ",", "0.678112646", ",", 
     "0.716063174", ",", "0.723398834", ",", "0.708518822", ",", 
     "0.873351825", ",", "0.768194807", ",", "0.717741813", ",", "0.74485805",
      ",", "0.831747239", ",", "0.794369457", ",", "0.645120875", ",", 
     "0.879291279", ",", "0.858928964", ",", "0.600900582", ",", 
     "0.847528135", ",", "0.904201635", ",", "0.716845153", ",", 
     "0.823350711", ",", "0.678512941", ",", "0.8753592", ",", "0.735675486", 
     ",", "0.939895715", ",", "0.738637042", ",", "0.890158872", ",", 
     "0.829928368", ",", "0.717738257", ",", "0.636257542", ",", 
     "0.831657533", ",", "0.78182081", ",", "0.713532952"}], "}"}]}], 
  ";"}]], "Input",
 CellChangeTimes->{{3.562264563264846*^9, 3.562264650010807*^9}, 
   3.5629183781115794`*^9}],

Cell[BoxData[
 RowBox[{"Do", "[", 
  RowBox[{
   RowBox[{
    RowBox[{"dw", "[", "j", "]"}], "=", 
    RowBox[{"dat8", "[", 
     RowBox[{"[", "j", "]"}], "]"}]}], ",", 
   RowBox[{"{", 
    RowBox[{"j", ",", "ALL"}], "}"}]}], "]"}]], "Input"],

Cell["Real exchange rate vs developping world", "Text",
 CellChangeTimes->{{3.5622645718443365`*^9, 3.5622645773306503`*^9}, {
  3.562918398066721*^9, 3.562918406286191*^9}}],

Cell[BoxData[
 RowBox[{
  RowBox[{"dat9", "=", 
   RowBox[{"{", 
    RowBox[{
    "1", ",", "0.4450", ",", ".3910", ",", ".7540", ",", ".6510", ",", 
     ".3850", ",", ".7940", ",", ".4300", ",", ".4400", ",", ".3010", ",", 
     ".3550", ",", ".3750", ",", ".4000", ",", ".4850", ",", ".5890", ",", 
     ".2740", ",", ".3430", ",", ".5200", ",", ".4000", ",", ".3670", ",", 
     ".5590", ",", ".5890", ",", ".3640", ",", ".6550", ",", ".5750", ",", 
     ".3870", ",", ".4060", ",", ".3120", ",", ".5060", ",", ".5710", ",", 
     ".6700", ",", ".6650", ",", ".5670", ",", ".4530", ",", ".3430", ",", 
     ".3080", ",", ".6490", ",", ".3720", ",", ".431"}], "}"}]}], 
  ";"}]], "Input",
 CellChangeTimes->{{3.5629183876431246`*^9, 3.5629184508647404`*^9}, {
   3.562918523844915*^9, 3.5629185309343204`*^9}, 3.5655075952063117`*^9}],

Cell[BoxData[
 RowBox[{"Do", "[", 
  RowBox[{
   RowBox[{
    RowBox[{"rer", "[", "j", "]"}], "=", 
    RowBox[{"dat9", "[", 
     RowBox[{"[", "j", "]"}], "]"}]}], ",", 
   RowBox[{"{", 
    RowBox[{"j", ",", "ALL"}], "}"}]}], "]"}]], "Input",
 CellChangeTimes->{{3.562918470711876*^9, 3.5629184773172536`*^9}}],

Cell["\<\
Mincerian return and years of schooling gap between high skilled and low \
skilled\
\>", "Text",
 CellChangeTimes->{{3.5630898139723854`*^9, 3.563089828745611*^9}}],

Cell[BoxData[{
 RowBox[{
  RowBox[{"dat10", "=", 
   RowBox[{"{", 
    RowBox[{
    "0.120", ",", "0.070", ",", "0.090", ",", "0.110", ",", "0.108", ",", 
     "0.070", ",", "0.084", ",", "0.070", ",", "0.072", ",", "0.065", ",", 
     "0.105", ",", "0.077", ",", "0.084", ",", "0.085", ",", "0.085", ",", 
     "0.070", ",", "0.115", ",", "0.080", ",", "0.065", ",", "0.094", ",", 
     "0.107", ",", "0.108", ",", "0.070", ",", "0.085", ",", "0.072", ",", 
     "0.070", ",", "0.065", ",", "0.055", ",", "0.110", ",", "0.108", ",", 
     "0.108", ",", "0.105", ",", "0.100", ",", "0.100", ",", "0.070", ",", 
     "0.104", ",", "0.108", ",", "0.091", ",", "0.110"}], "}"}]}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"dat11", "=", 
   RowBox[{"{", 
    RowBox[{
    "11.0", ",", "6.3", ",", "8.6", ",", "9.0", ",", "11.2", ",", "7.9", ",", 
     "9.0", ",", "7.1", ",", "8.5", ",", "7.9", ",", "10.4", ",", "9.4", ",", 
     "7.5", ",", "8.8", ",", "10.0", ",", "8.7", ",", "7.0", ",", "7.1", ",", 
     "9.1", ",", "7.7", ",", "8.3", ",", "11.9", ",", "8.2", ",", "11.3", ",",
      "8.6", ",", "7.3", ",", "7.6", ",", "7.4", ",", "12.8", ",", "12.0", 
     ",", "11.5", ",", "10.3", ",", "9.0", ",", "9.0", ",", "7.1", ",", "8.0",
      ",", "11.1", ",", "9.4", ",", "6.3"}], "}"}]}], ";"}]}], "Input",
 CellChangeTimes->{{3.563089728640235*^9, 3.563089776220319*^9}, {
   3.563089806484372*^9, 3.5630898820821047`*^9}, 3.5630981841654873`*^9, {
   3.5655199687128253`*^9, 3.565519974353651*^9}}],

Cell[BoxData[{
 RowBox[{"Do", "[", 
  RowBox[{
   RowBox[{
    RowBox[{"rho", "[", "j", "]"}], "=", 
    RowBox[{"dat10", "[", 
     RowBox[{"[", "j", "]"}], "]"}]}], ",", 
   RowBox[{"{", 
    RowBox[{"j", ",", "ALL"}], "}"}]}], "]"}], "\[IndentingNewLine]", 
 RowBox[{"Do", "[", 
  RowBox[{
   RowBox[{
    RowBox[{"gap", "[", "j", "]"}], "=", 
    RowBox[{"dat11", "[", 
     RowBox[{"[", "j", "]"}], "]"}]}], ",", 
   RowBox[{"{", 
    RowBox[{"j", ",", "ALL"}], "}"}]}], "]"}], "\[IndentingNewLine]", 
 RowBox[{"Do", "[", 
  RowBox[{
   RowBox[{
    RowBox[{"omega", "[", "j", "]"}], "=", 
    RowBox[{
     RowBox[{"(", 
      RowBox[{"1", "+", 
       RowBox[{"rho", "[", "j", "]"}]}], ")"}], "^", 
     RowBox[{"gap", "[", "j", "]"}]}]}], ",", 
   RowBox[{"{", 
    RowBox[{"j", ",", "ALL"}], "}"}]}], "]"}]}], "Input",
 CellChangeTimes->{{3.5630897851279345`*^9, 3.5630897888563414`*^9}, {
  3.5630898870117135`*^9, 3.5630898936573253`*^9}, {3.5630981313281946`*^9, 
  3.563098150921829*^9}, {3.563098203166321*^9, 3.5630982034939213`*^9}}],

Cell["correlates : redistribution % of dgp", "Text",
 CellChangeTimes->{{3.5635194427683125`*^9, 3.563519459928343*^9}}],

Cell[BoxData[{
 RowBox[{
  RowBox[{"dat12", "=", 
   RowBox[{"{", 
    RowBox[{
    "0", ",", "0.11960", ",", ".22140", ",", ".06800", ",", ".05140", ",", 
     ".22360", ",", ".07600", ",", ".15700", ",", ".13600", ",", ".18060", 
     ",", ".19170", ",", ".23970", ",", ".19470", ",", ".15570", ",", 
     ".06040", ",", ".16310", ",", ".13980", ",", ".15930", ",", ".18920", 
     ",", ".12230", ",", ".08680", ",", ".08680", ",", ".17550", ",", 
     ".05610", ",", ".16380", ",", ".19370", ",", ".14200", ",", ".20060", 
     ",", ".19050", ",", ".05290", ",", ".09720", ",", ".04430", ",", 
     ".19880", ",", ".16660", ",", ".21660", ",", ".16240", ",", ".04080", 
     ",", ".16670", ",", ".1663"}], "}"}]}], ";"}], "\[IndentingNewLine]", 
 RowBox[{"Do", "[", 
  RowBox[{
   RowBox[{
    RowBox[{"redis", "[", "j", "]"}], "=", 
    RowBox[{"dat12", "[", 
     RowBox[{"[", "j", "]"}], "]"}]}], ",", 
   RowBox[{"{", 
    RowBox[{"j", ",", "ALL"}], "}"}]}], "]"}]}], "Input",
 CellChangeTimes->{{3.563519364034974*^9, 3.5635194392427063`*^9}, {
  3.5635194703803606`*^9, 3.563519476760772*^9}}],

Cell["\<\
correlates: political participation index (Macao=Hong Kong, Brunei=Saudi \
Arabia, Bahamas=USA)\
\>", "Text",
 CellChangeTimes->{{3.5878108340974536`*^9, 3.5878108432640715`*^9}, {
  3.587810881577914*^9, 3.5878108855155816`*^9}, {3.589541416684149*^9, 
  3.5895414480133715`*^9}, {3.590231163787898*^9, 3.5902311662723813`*^9}}],

Cell[BoxData[{
 RowBox[{
  RowBox[{"dat13", "=", 
   RowBox[{"{", 
    RowBox[{
    "0", ",", "7.78", ",", "7.78", ",", "7.22", ",", "2.78", ",", "6.67", ",",
      "1.11", ",", "7.78", ",", "6.67", ",", "8.89", ",", "7.79", ",", "6.67",
      ",", "7.78", ",", "6.67", ",", "5", ",", "8.89", ",", "7.78", ",", 
     "8.33", ",", "6.11", ",", "5.56", ",", "7.22", ",", "1.11", ",", "7.78", 
     ",", "5", ",", "6.11", ",", "9.44", ",", "8.33", ",", "10", ",", "6.11", 
     ",", "1.67", ",", "1.11", ",", "2.78", ",", "6.67", ",", "6.11", ",", 
     "10", ",", "7.78", ",", "1.11", ",", "5", ",", "7.22"}], "}"}]}], 
  ";"}], "\n", 
 RowBox[{"Do", "[", 
  RowBox[{
   RowBox[{
    RowBox[{"polpart", "[", "j", "]"}], "=", 
    RowBox[{"dat13", "[", 
     RowBox[{"[", "j", "]"}], "]"}]}], ",", 
   RowBox[{"{", 
    RowBox[{"j", ",", "ALL"}], "}"}]}], "]"}]}], "Input",
 CellChangeTimes->{{3.5635225701664667`*^9, 3.5635225874184537`*^9}, {
   3.5635226694571457`*^9, 3.5635227715059834`*^9}, {3.5895390430852823`*^9, 
   3.5895390734457226`*^9}, {3.589541425825094*^9, 3.5895414537791977`*^9}, {
   3.5902311695537467`*^9, 3.5902311704600286`*^9}, 3.5939377483158574`*^9}],

Cell["average benefit receipt : migrant/native.", "Text",
 CellChangeTimes->{{3.5878108340974536`*^9, 3.5878108432640715`*^9}, {
  3.593254170837282*^9, 3.5932541769156466`*^9}, {3.593935854074766*^9, 
  3.593935855668605*^9}}],

Cell[BoxData[{
 RowBox[{
  RowBox[{"dat15", "=", 
   RowBox[{"{", 
    RowBox[{
    "0", ",", "0.353", ",", "0.579", ",", "0.238", ",", "0.201", ",", "0.584",
      ",", "0.256", ",", "0.436", ",", "0.389", ",", "0.489", ",", "0.513", 
     ",", "0.620", ",", "0.520", ",", "0.433", ",", "0.221", ",", "0.450", 
     ",", "0.398", ",", "0.441", ",", "0.508", ",", "0.359", ",", "0.280", 
     ",", "0.280", ",", "0.477", ",", "0.212", ",", "0.451", ",", "0.518", 
     ",", "0.403", ",", "0.533", ",", "0.510", ",", "0.204", ",", "0.303", 
     ",", "0.185", ",", "0.529", ",", "0.457", ",", "0.569", ",", "0.448", 
     ",", "0.178", ",", "0.458", ",", "0.457"}], "}"}]}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{"Do", "[", 
  RowBox[{
   RowBox[{
    RowBox[{"benef", "[", "j", "]"}], "=", 
    RowBox[{"dat15", "[", 
     RowBox[{"[", "j", "]"}], "]"}]}], ",", 
   RowBox[{"{", 
    RowBox[{"j", ",", "ALL"}], "}"}]}], "]"}]}], "Input",
 CellChangeTimes->{{3.5878107573603334`*^9, 3.587810819128169*^9}, {
   3.5878109325328646`*^9, 3.587810956189958*^9}, {3.590411705374859*^9, 
   3.5904117095937576`*^9}, 3.590411781127515*^9, 3.5904118567239175`*^9, 
   3.5916136415254345`*^9, 3.591613743060424*^9, {3.593868927378454*^9, 
   3.593868928347269*^9}, {3.5938689989438925`*^9, 3.593868999600173*^9}, 
   3.593869185513994*^9, {3.593935857559307*^9, 3.593935860934443*^9}, 
   3.5939377636602507`*^9, {3.5945485043742437`*^9, 3.594548629358194*^9}, {
   3.5951333533274636`*^9, 3.59513335378059*^9}}],

Cell["migration level desired. unskilled - skilled", "Text",
 CellChangeTimes->{{3.5878108340974536`*^9, 3.5878108432640715`*^9}, {
  3.587810881577914*^9, 3.5878108855155816`*^9}, {3.590231176163329*^9, 
  3.5902311958359165`*^9}}],

Cell[BoxData[{
 RowBox[{
  RowBox[{"dat20", "=", 
   RowBox[{"{", 
    RowBox[{
    "0", ",", "0.731", ",", "0.715", ",", "0.726", ",", "0.703", ",", "0.608",
      ",", "0.703", ",", "0.796", ",", "0.746", ",", "0.710", ",", "0.775", 
     ",", "0.578", ",", "0.636", ",", "0.746", ",", "0.595", ",", "0.722", 
     ",", "0.877", ",", "0.692", ",", "0.628", ",", "0.760", ",", "0.763", 
     ",", "0.703", ",", "0.608", ",", "0.595", ",", "0.746", ",", "0.610", 
     ",", "0.741", ",", "0.569", ",", "0.800", ",", "0.703", ",", "0.703", 
     ",", "0.595", ",", "0.830", ",", "0.809", ",", "0.686", ",", "0.822", 
     ",", "0.703", ",", "0.537", ",", "0.726"}], "}"}]}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{"Do", "[", 
  RowBox[{
   RowBox[{
    RowBox[{"shiftL", "[", "j", "]"}], "=", 
    RowBox[{"dat20", "[", 
     RowBox[{"[", "j", "]"}], "]"}]}], ",", 
   RowBox[{"{", 
    RowBox[{"j", ",", "ALL"}], "}"}]}], "]"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"dat21", "=", 
   RowBox[{"{", 
    RowBox[{
    "0", ",", "1.250", ",", "1.732", ",", "1.212", ",", "1.373", ",", "1.514",
      ",", "1.373", ",", "1.190", ",", "1.368", ",", "1.281", ",", "1.257", 
     ",", "1.447", ",", "1.702", ",", "1.368", ",", "1.470", ",", "1.301", 
     ",", "1.180", ",", "1.322", ",", "1.552", ",", "1.317", ",", "1.282", 
     ",", "1.373", ",", "1.514", ",", "1.470", ",", "1.368", ",", "1.392", 
     ",", "1.463", ",", "1.453", ",", "1.281", ",", "1.373", ",", "1.373", 
     ",", "1.470", ",", "1.199", ",", "1.270", ",", "1.408", ",", "1.193", 
     ",", "1.373", ",", "1.534", ",", "1.212"}], "}"}]}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{"Do", "[", 
  RowBox[{
   RowBox[{
    RowBox[{"shiftH", "[", "j", "]"}], "=", 
    RowBox[{"dat21", "[", 
     RowBox[{"[", "j", "]"}], "]"}]}], ",", 
   RowBox[{"{", 
    RowBox[{"j", ",", "ALL"}], "}"}]}], "]"}]}], "Input",
 CellChangeTimes->{{3.5635225701664667`*^9, 3.5635225874184537`*^9}, {
  3.5635226694571457`*^9, 3.5635227715059834`*^9}, {3.590231198117222*^9, 
  3.5902312776981645`*^9}, {3.590231315761975*^9, 3.590231397421112*^9}, {
  3.590295018235921*^9, 3.5902951157237234`*^9}, {3.590411050842435*^9, 
  3.590411154127307*^9}}],

Cell["calibrating the production function", "Text",
 CellChangeTimes->{{3.5878108882187757`*^9, 3.5878108945002766`*^9}}],

Cell[BoxData[{
 RowBox[{
  RowBox[{"dat14", "=", 
   RowBox[{"{", 
    RowBox[{
    "1.00", ",", "1.16", ",", "0.98", ",", "0.82", ",", "0.60", ",", "1.03", 
     ",", "0.90", ",", "1.16", ",", "1.05", ",", "0.74", ",", "1.00", ",", 
     "0.82", ",", "0.81", ",", "1.05", ",", "1.00", ",", "0.74", ",", "1.12", 
     ",", "0.99", ",", "1.05", ",", "0.99", ",", "0.99", ",", "0.60", ",", 
     "1.03", ",", "1.00", ",", "1.05", ",", "1.03", ",", "1.16", ",", "1.00", 
     ",", "1.04", ",", "\n", "0.60", ",", "0.60", ",", "1.00", ",", "0.98", 
     ",", "1.04", ",", "0.84", ",", "0.98", ",", "0.60", ",", "0.86", ",", 
     "0.82"}], "}"}]}], ";"}], "\n", 
 RowBox[{"Do", "[", 
  RowBox[{
   RowBox[{
    RowBox[{"wagenat", "[", "j", "]"}], "=", 
    RowBox[{"1", "/", 
     RowBox[{"dat14", "[", 
      RowBox[{"[", "j", "]"}], "]"}]}]}], ",", 
   RowBox[{"{", 
    RowBox[{"j", ",", "ALL"}], "}"}]}], "]"}]}], "Input",
 CellChangeTimes->{{3.587789848767271*^9, 3.5877898622990837`*^9}, {
  3.587791613583675*^9, 3.5877916901024113`*^9}}],

Cell[BoxData[{
 RowBox[{
  RowBox[{"\[Sigma]", "=", "20"}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"Do", "[", 
   RowBox[{
    RowBox[{
     RowBox[{
      RowBox[{"tp", "[", "j", "]"}], "=", 
      RowBox[{
       RowBox[{"wagenat", "[", "j", "]"}], " ", 
       RowBox[{"dw", "[", "j", "]"}], 
       RowBox[{
        RowBox[{"(", 
         RowBox[{
          RowBox[{"n", "[", "j", "]"}], "/", 
          RowBox[{"(", 
           RowBox[{
            RowBox[{"dw", "[", "j", "]"}], " ", 
            RowBox[{"mm", "[", "j", "]"}]}], ")"}]}], ")"}], "^", 
        RowBox[{"(", 
         RowBox[{"1", "/", "\[Sigma]"}], ")"}]}]}]}], ";", 
     "\[IndentingNewLine]", 
     RowBox[{
      RowBox[{"sh", "[", "j", "]"}], "=", 
      RowBox[{
       RowBox[{"tp", "[", "j", "]"}], "/", 
       RowBox[{"(", 
        RowBox[{"(", 
         RowBox[{"1", "+", 
          RowBox[{"tp", "[", "j", "]"}]}], ")"}], ")"}]}]}]}], ",", 
    RowBox[{"{", 
     RowBox[{"j", ",", "HIGHINCOME"}], "}"}]}], "]"}], ";", 
  RowBox[{
   RowBox[{"sh", "[", "1", "]"}], "=", "1"}], ";"}]}], "Input",
 CellChangeTimes->{{3.5877898654241858`*^9, 3.5877898980817814`*^9}, {
   3.587789945614951*^9, 3.587789953177755*^9}, {3.5877899895073204`*^9, 
   3.587790048525356*^9}, {3.5877900834955144`*^9, 3.587790087198792*^9}, {
   3.58779051529471*^9, 3.587790521998094*^9}, 3.5877917654179535`*^9, {
   3.5877918229983788`*^9, 3.587791824373434*^9}, {3.587791964441594*^9, 
   3.5877920002555356`*^9}, {3.5877922566186805`*^9, 
   3.5877922605406885`*^9}, {3.5877922974953055`*^9, 3.587792298432869*^9}, {
   3.5877925092471533`*^9, 3.5877925195444703`*^9}, {3.5878129748860917`*^9, 
   3.5878129759330325`*^9}, {3.587813348747781*^9, 3.5878133493103046`*^9}, {
   3.5879821091109657`*^9, 3.5879821096422434`*^9}, {3.5879822700699887`*^9, 
   3.587982270694987*^9}, {3.587982533755398*^9, 3.5879825340522833`*^9}, {
   3.5879852003756375`*^9, 3.5879852032507167`*^9}, {3.587985489386392*^9, 
   3.587985497636688*^9}, {3.58798568005186*^9, 3.58798568061438*^9}, {
   3.587987305350668*^9, 3.5879873055537815`*^9}, {3.590295137490102*^9, 
   3.590295139083931*^9}, 3.5903222464611692`*^9, 3.5903224272593875`*^9, {
   3.5904118491924024`*^9, 3.590411850223689*^9}, {3.5904120527810555`*^9, 
   3.590412054249858*^9}, {3.593767787615159*^9, 3.5937677886464233`*^9}, {
   3.5937678415392036`*^9, 3.5937678424767694`*^9}, {3.5937679213081045`*^9, 
   3.5937679232925606`*^9}, {3.593768071893182*^9, 3.593768072127565*^9}, 
   3.5937778023035636`*^9}],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"Table", "[", 
  RowBox[{
   RowBox[{"sh", "[", "j", "]"}], ",", 
   RowBox[{"{", 
    RowBox[{"j", ",", "ALL"}], "}"}]}], "]"}]], "Input",
 CellChangeTimes->{{3.593777737035306*^9, 3.5937777376759553`*^9}}],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
  "1", ",", "0.4308948787988009`", ",", "0.45160089836784534`", ",", 
   "0.5465760633568917`", ",", "0.6073337151861377`", ",", 
   "0.45157639917010806`", ",", "0.4905185688596289`", ",", 
   "0.4197953572651073`", ",", "0.4954528486719443`", ",", 
   "0.5229162691051761`", ",", "0.47256990669814697`", ",", 
   "0.5044051996634727`", ",", "0.5015673896527701`", ",", 
   "0.48609401291159116`", ",", "0.44395044478133316`", ",", 
   "0.5414517478174393`", ",", "0.4507866129665542`", ",", 
   "0.47012699949667186`", ",", "0.4808840022578471`", ",", 
   "0.4636808723951199`", ",", "0.5514845599374969`", ",", 
   "0.5954060418796483`", ",", "0.4073439572472327`", ",", 
   "0.4967321938902815`", ",", "0.5358539999452798`", ",", 
   "0.44614887654357693`", ",", "0.45316736086592824`", ",", 
   "0.44774134053446857`", ",", "0.496865184935688`", ",", 
   "0.5438934467658486`", ",", "0.6256405441779669`", ",", 
   "0.45117099470299615`", ",", "0.5233262103491079`", ",", 
   "0.4872740285988801`", ",", "0.49795237861446306`", ",", 
   "0.4255459517597972`", ",", "0.5767092027546156`", ",", 
   "0.5172731905044582`", ",", "0.4988097261548679`"}], "}"}]], "Output",
 CellChangeTimes->{{3.593777788427997*^9, 3.593777804975548*^9}, {
   3.5937788124071026`*^9, 3.593778834174721*^9}, 3.593860089569893*^9, 
   3.593868942957212*^9, 3.593869009913066*^9, 3.5939245792427874`*^9, 
   3.5939335562395897`*^9, 3.5939359256089277`*^9, 3.5939377863330226`*^9, 
   3.594234139204895*^9, 3.594279050827877*^9, 3.5942791549424596`*^9, 
   3.594279251381829*^9, {3.5945396316404743`*^9, 3.5945396477817545`*^9}, {
   3.5945486117480745`*^9, 3.594548641593041*^9}, 3.5951334944738097`*^9}]
}, Open  ]],

Cell[BoxData[{
 RowBox[{
  RowBox[{
   RowBox[{"CES", "[", 
    RowBox[{"a_", ",", "b_", ",", "j_"}], "]"}], "=", 
   RowBox[{
    RowBox[{"(", " ", 
     RowBox[{
      RowBox[{
       RowBox[{"sh", "[", "j", "]"}], 
       RowBox[{"a", "^", 
        RowBox[{"(", 
         RowBox[{
          RowBox[{"(", 
           RowBox[{"\[Sigma]", "-", "1"}], ")"}], "/", "\[Sigma]"}], 
         ")"}]}]}], "+", 
      RowBox[{
       RowBox[{"(", 
        RowBox[{"1", "-", 
         RowBox[{"sh", "[", "j", "]"}]}], ")"}], 
       RowBox[{"b", "^", 
        RowBox[{"(", 
         RowBox[{
          RowBox[{"(", 
           RowBox[{"\[Sigma]", "-", "1"}], ")"}], "/", "\[Sigma]"}], 
         ")"}]}]}]}], ")"}], "^", 
    RowBox[{"(", 
     RowBox[{"\[Sigma]", "/", 
      RowBox[{"(", 
       RowBox[{"\[Sigma]", "-", "1"}], ")"}]}], ")"}]}]}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{
   RowBox[{"dCES1", "[", 
    RowBox[{"a_", ",", "b_", ",", "j_"}], "]"}], "=", 
   RowBox[{"D", "[", 
    RowBox[{
     RowBox[{"CES", "[", 
      RowBox[{"a", ",", "b", ",", "j"}], "]"}], ",", "a"}], "]"}]}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{
   RowBox[{"dCES2", "[", 
    RowBox[{"a_", ",", "b_", ",", "j_"}], "]"}], "=", 
   RowBox[{"D", "[", 
    RowBox[{
     RowBox[{"CES", "[", 
      RowBox[{"a", ",", "b", ",", "j"}], "]"}], ",", "b"}], "]"}]}], 
  ";"}]}], "Input",
 CellChangeTimes->{{3.5824551019689207`*^9, 3.582455152408182*^9}, 
   3.5824553120699053`*^9, {3.582523563857148*^9, 3.582523566482209*^9}, {
   3.5825240134823046`*^9, 3.582524037529976*^9}, {3.582524425083109*^9, 
   3.582524435177205*^9}, {3.5825247808270006`*^9, 3.5825247904835873`*^9}, {
   3.5826036476067333`*^9, 3.5826036522631707`*^9}, {3.5826039774931707`*^9, 
   3.582603981712098*^9}, {3.5826134180477133`*^9, 3.582613421047817*^9}, {
   3.5826135716153207`*^9, 3.5826135732559996`*^9}, {3.5877901000274363`*^9, 
   3.5877901333100123`*^9}, 3.587795532645626*^9, {3.5877966308291206`*^9, 
   3.5877966390482025`*^9}, 3.587796827371018*^9, {3.587805551694393*^9, 
   3.5878055519756556`*^9}, {3.5878056058528304`*^9, 3.5878056104936438`*^9}}],

Cell["share of low skilled labor in output ", "Text",
 CellChangeTimes->{{3.5619894515510707`*^9, 3.5619894632042913`*^9}, {
  3.5655200958259344`*^9, 3.5655200984197755`*^9}}],

Cell[BoxData[
 RowBox[{"\[IndentingNewLine]", 
  RowBox[{"Do", "[", 
   RowBox[{
    RowBox[{
     RowBox[{
      RowBox[{"alpk", "[", "j", "]"}], "=", ".365"}], ";", 
     RowBox[{
      RowBox[{"alp", "[", "j", "]"}], "=", 
      FractionBox[
       RowBox[{
        RowBox[{"(", 
         RowBox[{"1", "-", 
          RowBox[{"alpk", "[", "j", "]"}]}], ")"}], 
        RowBox[{"(", 
         RowBox[{"CES", "[", 
          RowBox[{
           RowBox[{"n", "[", "j", "]"}], ",", 
           RowBox[{
            RowBox[{"dw", "[", "j", "]"}], " ", 
            RowBox[{"mm", "[", "j", "]"}]}], ",", "j"}], "]"}], ")"}]}], 
       RowBox[{"(", 
        RowBox[{
         RowBox[{
          RowBox[{"(", 
           RowBox[{
            RowBox[{"omega", "[", "j", "]"}], "-", "1"}], ")"}], 
          RowBox[{"nH", "[", "j", "]"}], 
          RowBox[{"dCES1", "[", 
           RowBox[{
            RowBox[{"n", "[", "j", "]"}], ",", 
            RowBox[{
             RowBox[{"dw", "[", "j", "]"}], " ", 
             RowBox[{"mm", "[", "j", "]"}]}], ",", "j"}], "]"}]}], "+", 
         RowBox[{"CES", "[", 
          RowBox[{
           RowBox[{"n", "[", "j", "]"}], ",", 
           RowBox[{
            RowBox[{"dw", "[", "j", "]"}], " ", 
            RowBox[{"mm", "[", "j", "]"}]}], ",", "j"}], "]"}]}], ")"}]]}]}], 
    ",", 
    RowBox[{"{", 
     RowBox[{"j", ",", "ALL"}], "}"}]}], "]"}]}]], "Input",
 CellChangeTimes->{{3.5655198629902654`*^9, 3.5655199816038847`*^9}, {
   3.5655200439647007`*^9, 3.5655200520587435`*^9}, {3.565591705576044*^9, 
   3.565591740221052*^9}, {3.565591830182119*^9, 3.5655918467139673`*^9}, {
   3.5655924175720634`*^9, 3.56559241807211*^9}, {3.565592505598998*^9, 
   3.56559250742719*^9}, 3.5655925452879467`*^9, {3.5824551707213116`*^9, 
   3.582455182487341*^9}, {3.582605245682646*^9, 3.582605251295498*^9}, {
   3.587790147201188*^9, 3.5877901475137005`*^9}, {3.58779190701742*^9, 
   3.587791907345559*^9}, {3.5878055633042383`*^9, 3.5878055795080175`*^9}, {
   3.593777820648061*^9, 3.5937778303515882`*^9}}],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"Table", "[", 
  RowBox[{
   RowBox[{"alp", "[", "j", "]"}], ",", 
   RowBox[{"{", 
    RowBox[{"j", ",", "ALL"}], "}"}]}], "]"}]], "Input",
 CellChangeTimes->{{3.5937650650223007`*^9, 3.5937650925078173`*^9}}],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
  "0.5869889147641731`", ",", "0.5785355922386426`", ",", 
   "0.5854014371992745`", ",", "0.5637740161971249`", ",", 
   "0.5705650967812983`", ",", "0.5637942064191159`", ",", 
   "0.6050717781342841`", ",", "0.5675008817381146`", ",", 
   "0.5485180297491041`", ",", "0.5918297064177228`", ",", 
   "0.5621700005753946`", ",", "0.5826125809205175`", ",", 
   "0.5713626631494918`", ",", "0.5533888911625547`", ",", 
   "0.5821464532417645`", ",", "0.5806394940382837`", ",", 
   "0.5329449280318422`", ",", "0.5390878168613877`", ",", 
   "0.6082061374146589`", ",", "0.5338428822045322`", ",", 
   "0.5308897803734852`", ",", "0.534604038441425`", ",", 
   "0.5871848291234029`", ",", "0.5725857731624833`", ",", 
   "0.6052849150646238`", ",", "0.5799251376686542`", ",", 
   "0.5636311659468293`", ",", "0.5994453274846056`", ",", 
   "0.57252353402158`", ",", "0.46894378423090805`", ",", 
   "0.5224559383594823`", ",", "0.556951414342819`", ",", 
   "0.5720472205316526`", ",", "0.5454951510043494`", ",", 
   "0.5790597245967173`", ",", "0.5498900194311402`", ",", 
   "0.5187985353236074`", ",", "0.5644369708151724`", ",", 
   "0.4925974829748957`"}], "}"}]], "Output",
 CellChangeTimes->{
  3.5937650956954217`*^9, 3.593765529417716*^9, 3.5937677915371656`*^9, 
   3.5937678552585115`*^9, 3.593767933886716*^9, 3.593768081034154*^9, 
   3.5937756799157047`*^9, 3.593777845383444*^9, {3.5937788124383564`*^9, 
   3.593778834205971*^9}, 3.5938600896167707`*^9, 3.5938689429884634`*^9, 
   3.5938690099443173`*^9, 3.5939245792740374`*^9, 3.5939335562552176`*^9, 
   3.593935925624553*^9, 3.593937786364276*^9, 3.5942341392360954`*^9, 
   3.5942790508590765`*^9, 3.5942791549892597`*^9, 3.594279251428629*^9, {
   3.5945396316560974`*^9, 3.5945396478130054`*^9}, {3.5945486117637005`*^9, 
   3.594548641624292*^9}, 3.595133494505061*^9}]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"Table", "[", 
  RowBox[{
   RowBox[{"1", "-", 
    RowBox[{"alpk", "[", "j", "]"}], "-", 
    RowBox[{"alp", "[", "j", "]"}]}], ",", 
   RowBox[{"{", 
    RowBox[{"j", ",", "ALL"}], "}"}]}], "]"}]], "Input",
 CellChangeTimes->{{3.593777871040766*^9, 3.5937778792754745`*^9}}],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
  "0.04801108523582687`", ",", "0.056464407761357416`", ",", 
   "0.0495985628007255`", ",", "0.07122598380287515`", ",", 
   "0.06443490321870171`", ",", "0.07120579358088408`", ",", 
   "0.029928221865715865`", ",", "0.06749911826188537`", ",", 
   "0.08648197025089588`", ",", "0.0431702935822772`", ",", 
   "0.07282999942460544`", ",", "0.05238741907948252`", ",", 
   "0.06363733685050821`", ",", "0.08161110883744527`", ",", 
   "0.0528535467582355`", ",", "0.054360505961716266`", ",", 
   "0.10205507196815777`", ",", "0.09591218313861227`", ",", 
   "0.02679386258534111`", ",", "0.10115711779546777`", ",", 
   "0.10411021962651479`", ",", "0.100395961558575`", ",", 
   "0.047815170876597146`", ",", "0.06241422683751674`", ",", 
   "0.029715084935376224`", ",", "0.05507486233134584`", ",", 
   "0.07136883405317074`", ",", "0.03555467251539446`", ",", 
   "0.06247646597842005`", ",", "0.16605621576909196`", ",", 
   "0.11254406164051767`", ",", "0.07804858565718098`", ",", 
   "0.06295277946834743`", ",", "0.08950484899565059`", ",", 
   "0.055940275403282724`", ",", "0.08510998056885977`", ",", 
   "0.11620146467639259`", ",", "0.0705630291848276`", ",", 
   "0.1424025170251043`"}], "}"}]], "Output",
 CellChangeTimes->{
  3.593777880212986*^9, {3.5937788124383564`*^9, 3.5937788342215967`*^9}, 
   3.5938600896323957`*^9, 3.5938689429884634`*^9, 3.593869009959942*^9, 
   3.5939245792896624`*^9, 3.5939335562708406`*^9, 3.593935925640179*^9, 
   3.5939377863799*^9, 3.594234139251695*^9, 3.594279050890277*^9, 
   3.5942791550360594`*^9, 3.594279251444229*^9, {3.5945396316717243`*^9, 
   3.5945396478442564`*^9}, {3.5945486117793264`*^9, 3.5945486416399174`*^9}, 
   3.5951334945363216`*^9}]
}, Open  ]]
}, Open  ]]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell["calibration of productivity", "Section",
 CellChangeTimes->{{3.4057850862771997`*^9, 3.4057850877904*^9}, {
  3.4223299121305447`*^9, 3.4223299144549446`*^9}}],

Cell["productivity including fixed factors", "Text",
 CellChangeTimes->{{3.4057850862771997`*^9, 3.4057850877904*^9}, {
  3.4058034360186*^9, 3.4058034419466*^9}, {3.55999183091851*^9, 
  3.5599918474504557`*^9}}],

Cell[BoxData[
 RowBox[{"Do", "[", 
  RowBox[{
   RowBox[{
    RowBox[{"\[Mu]", "[", "j", "]"}], "=", 
    FractionBox[
     RowBox[{"y", "[", "j", "]"}], 
     SuperscriptBox[
      RowBox[{"(", 
       RowBox[{"CES", "[", 
        RowBox[{
         RowBox[{"n", "[", "j", "]"}], ",", 
         RowBox[{
          RowBox[{"dw", "[", "j", "]"}], 
          RowBox[{"mm", "[", "j", "]"}]}], ",", "j"}], "]"}], ")"}], 
      RowBox[{"alp", "[", "j", "]"}]]]}], ",", 
   RowBox[{"{", 
    RowBox[{"j", ",", "ALL"}], "}"}]}], "]"}]], "Input",
 CellChangeTimes->{{3.4223302345357447`*^9, 3.4223302776073446`*^9}, 
   3.4223317739125443`*^9, {3.450780146984375*^9, 3.45078014740625*^9}, 
   3.495263965640625*^9, {3.49526414578125*^9, 3.4952641604375*^9}, {
   3.49526439109375*^9, 3.495264402421875*^9}, 3.49526477834375*^9, {
   3.495264828265625*^9, 3.495264829921875*^9}, {3.5599752905752373`*^9, 
   3.5599753137256775`*^9}, {3.5599917445665708`*^9, 3.559991757329301*^9}, {
   3.560070892877824*^9, 3.560070893189824*^9}, {3.562264875705042*^9, 
   3.5622648764226427`*^9}, {3.582455229129541*^9, 3.5824552347235093`*^9}, {
   3.587791926877571*^9, 3.5877919271744843`*^9}, 3.5937779164801164`*^9}],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"Table", "[", 
  RowBox[{
   RowBox[{"\[Mu]", "[", "j", "]"}], ",", 
   RowBox[{"{", 
    RowBox[{"j", ",", "ALL"}], "}"}]}], "]"}]], "Input"],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
  "3097.3533553801963`", ",", "3167.002374409439`", ",", "2061.475378666455`",
    ",", "385.71782454953035`", ",", "504.38156510690067`", ",", 
   "2596.758759370017`", ",", "460.45887977962275`", ",", 
   "4566.504858964073`", ",", "746.3829131582119`", ",", "1661.849679077083`",
    ",", "1819.4335265750594`", ",", "4151.873951640819`", ",", 
   "5547.181019272564`", ",", "1789.9141688792968`", ",", 
   "1831.1114342943004`", ",", "554.7987978306894`", ",", 
   "2538.942877423007`", ",", "2286.2470863362723`", ",", 
   "3231.897655465897`", ",", "10551.583764406934`", ",", 
   "4463.637728612344`", ",", "1287.7181015138885`", ",", 
   "1227.613612543804`", ",", "547.2507454463292`", ",", 
   "257.81230540523234`", ",", "2996.507434012552`", ",", 
   "1302.1045125510136`", ",", "1692.1953146137075`", ",", 
   "1603.5173546386131`", ",", "862.9119620311399`", ",", 
   "3252.068128357906`", ",", "1660.0910032870381`", ",", 
   "719.5722963788768`", ",", "4206.612372664009`", ",", 
   "1919.3589587856766`", ",", "2850.4532136822836`", ",", 
   "1901.424360118164`", ",", "4882.760379635689`", ",", 
   "33797.86608107591`"}], "}"}]], "Output",
 CellChangeTimes->{
  3.582523394257541*^9, 3.582523686580084*^9, 3.5825241149545116`*^9, 
   3.5825244386460476`*^9, 3.582524803796537*^9, 3.582525079188161*^9, 
   3.582527897906349*^9, 3.582603655700754*^9, 3.5826061768097677`*^9, 
   3.582613425626066*^9, 3.582613583037554*^9, 3.5877919327371826`*^9, 
   3.58779201042782*^9, 3.5877925539208317`*^9, 3.5877925900316668`*^9, 
   3.5877955510245476`*^9, {3.587805616697019*^9, 3.5878056201034064`*^9}, 
   3.587805949857917*^9, 3.587806213461248*^9, {3.587806309136545*^9, 
   3.5878063280590963`*^9}, 3.587806551738976*^9, {3.587810950721012*^9, 
   3.5878109733936996`*^9}, 3.5878130019239535`*^9, 3.5878133638576717`*^9, 
   3.5878157690779476`*^9, 3.5878158416328*^9, 3.587816132402255*^9, 
   3.58781620245618*^9, 3.5878800848675203`*^9, 3.5878801775271497`*^9, 
   3.5878802173723555`*^9, 3.5879821134392495`*^9, 3.5879822738357267`*^9, 
   3.5879825374430046`*^9, 3.5879842717890396`*^9, 3.5879848707542114`*^9, 
   3.5879849641951184`*^9, 3.5879855248876567`*^9, 3.5879855879846807`*^9, 
   3.5879856443773637`*^9, 3.587985684598896*^9, 3.587985813869238*^9, 
   3.5879858567145505`*^9, 3.5879859072320194`*^9, 3.5879859608589745`*^9, 
   3.5879873199918013`*^9, 3.588331351914299*^9, 3.5892906988763947`*^9, 
   3.5893511466089907`*^9, 3.5896311230607367`*^9, 3.590231428328415*^9, 
   3.5902951289585505`*^9, 3.5903222505394254`*^9, 3.590322344995841*^9, 
   3.590322444338113*^9, 3.590411166924631*^9, 3.590411724031763*^9, 
   3.5904117942842283`*^9, 3.5904118723494644`*^9, 3.590412064625222*^9, 
   3.590412226125271*^9, 3.591613671260905*^9, 3.591613760186056*^9, 
   3.593254221589266*^9, 3.593765095711047*^9, 3.593765529433342*^9, 
   3.593767791552791*^9, 3.5937678552741365`*^9, 3.59376793390234*^9, 
   3.593768081049779*^9, 3.5937756799313307`*^9, 3.593777923308519*^9, {
   3.5937788124539804`*^9, 3.5937788342372255`*^9}, 3.5938600896792727`*^9, 
   3.5938689430197153`*^9, 3.593869009975568*^9, 3.5939245793052883`*^9, 
   3.5939335562864685`*^9, 3.5939359256558046`*^9, 3.593937786411153*^9, 
   3.594234139282895*^9, 3.594279050905877*^9, 3.59427915506726*^9, 
   3.5942792514754295`*^9, {3.594539631687351*^9, 3.5945396478755083`*^9}, {
   3.5945486117949524`*^9, 3.5945486416555433`*^9}, 3.5951334945519376`*^9}]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell["saving the results", "Section",
 CellChangeTimes->{{3.4057850862771997`*^9, 3.4057850877904*^9}, {
  3.4223299121305447`*^9, 3.4223299144549446`*^9}, {3.422330097271344*^9, 
  3.4223300991121445`*^9}}],

Cell[BoxData[
 RowBox[{
  RowBox[{"DumpSave", "[", 
   RowBox[{"\"\<migration-data20.mx\>\"", ",", "\"\<Global`\>\""}], "]"}], 
  ";"}]], "Input",
 CellChangeTimes->{{3.4214887280081997`*^9, 3.4214887977942*^9}, {
   3.4214889554642*^9, 3.4214889853892*^9}, {3.4214894332592*^9, 
   3.4214894343382*^9}, {3.4214895448252*^9, 3.4214895763592*^9}, 
   3.4214896413972*^9, {3.45076582896875*^9, 3.450765829921875*^9}, {
   3.4681532958125*^9, 3.468153297953125*^9}, {3.553079141159404*^9, 
   3.5530791432030077`*^9}, {3.5530792461631885`*^9, 3.5530792463659887`*^9}, 
   3.5579974158474655`*^9, {3.5592088065109606`*^9, 3.5592088089133654`*^9}, {
   3.559972675819042*^9, 3.5599726761310425`*^9}, {3.562411332128936*^9, 
   3.562411332834976*^9}, {3.5824552664277253`*^9, 3.5824552666621075`*^9}, {
   3.5824553313205757`*^9, 3.582455340602147*^9}, {3.582524796374436*^9, 
   3.58252479670257*^9}, 3.5825250746255307`*^9, {3.59023140845275*^9, 
   3.590231408624606*^9}, {3.593254150347234*^9, 3.5932541512225466`*^9}, {
   3.593765035333612*^9, 3.593765035817984*^9}, {3.593778829049512*^9, 
   3.5937788295495377`*^9}, {3.5942341193460608`*^9, 3.594234134290887*^9}, {
   3.5945396189680815`*^9, 3.5945396202650137`*^9}, {3.5951333996730766`*^9, 
   3.5951334038607435`*^9}}],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{
  RowBox[{"Table", "[", 
   RowBox[{
    RowBox[{"{", 
     RowBox[{
      RowBox[{"id", "[", "j", "]"}], ",", 
      RowBox[{"N", "[", 
       RowBox[{
        RowBox[{"n", "[", "j", "]"}], "+", 
        RowBox[{"mm", "[", "j", "]"}]}], "]"}], ",", 
      RowBox[{
       RowBox[{"nH", "[", "j", "]"}], "/", 
       RowBox[{"(", 
        RowBox[{
         RowBox[{"n", "[", "j", "]"}], "+", 
         RowBox[{"mm", "[", "j", "]"}]}], ")"}]}], ",", 
      RowBox[{
       RowBox[{"mm", "[", "j", "]"}], "/", 
       RowBox[{"(", 
        RowBox[{
         RowBox[{"n", "[", "j", "]"}], "+", 
         RowBox[{"mm", "[", "j", "]"}]}], ")"}]}], ",", 
      RowBox[{"rho", "[", "j", "]"}], ",", 
      RowBox[{"gap", "[", "j", "]"}], ",", 
      RowBox[{"N", "[", 
       RowBox[{
        RowBox[{"y", "[", "j", "]"}], "/", 
        RowBox[{"(", 
         RowBox[{
          RowBox[{"n", "[", "j", "]"}], "+", 
          RowBox[{"mm", "[", "j", "]"}]}], ")"}]}], "]"}], ",", 
      RowBox[{"dw", "[", "j", "]"}], ",", 
      RowBox[{"ginc", "[", "j", "]"}], ",", 
      RowBox[{"wagenat", "[", "j", "]"}], ",", 
      RowBox[{"benef", "[", "j", "]"}], ",", 
      RowBox[{"1", "/", 
       RowBox[{"rer", "[", "j", "]"}]}], ",", 
      RowBox[{"aid", "[", "j", "]"}]}], "}"}], ",", 
    RowBox[{"{", 
     RowBox[{"j", ",", 
      RowBox[{"Join", "[", 
       RowBox[{
        RowBox[{"{", "1", "}"}], ",", "OECD"}], "]"}]}], "}"}]}], "]"}], "//",
   "TableForm"}]], "Input",
 CellChangeTimes->{{3.563077984044156*^9, 3.563077989634164*^9}, {
   3.5630780450242414`*^9, 3.563078147554385*^9}, {3.563078196034453*^9, 
   3.5630781971744547`*^9}, {3.5630782922155876`*^9, 
   3.5630783085666103`*^9}, {3.563089919756171*^9, 3.5630899231413765`*^9}, {
   3.563098239701585*^9, 3.5630982439135923`*^9}, {3.565194332306974*^9, 
   3.56519439264788*^9}, {3.565195691377762*^9, 3.565195697258972*^9}, {
   3.5657780565270634`*^9, 3.565778056745824*^9}, 3.5657821414369497`*^9, 
   3.5657821732194195`*^9, {3.587792074792858*^9, 3.5877920842307663`*^9}, {
   3.587987336929946*^9, 3.587987339148773*^9}, {3.59513336745301*^9, 
   3.5951333888445325`*^9}, {3.5951334697540812`*^9, 3.5951335179903994`*^9}}],

Cell[BoxData[
 TagBox[GridBox[{
    {"\<\"Developing\"\>", "2.490589`*^6", "0.033`", "0", "0.12`", "11.`", 
     "7.0671953501762035`", "1", "0.829`", "1.`", "0", "1", "0"},
    {"\<\"Australia\"\>", "12520.81331044`", "0.18600000000000003`", 
     "0.08073064308028394`", "0.07`", "6.3`", "35.93249007433605`", 
     "0.767485387`", "0.712`", "0.8620689655172414`", "0.353`", 
     "2.247191011235955`", "0.5551303052742501`"},
    {"\<\"Austria\"\>", "5801.8981498699995`", "0.077`", 
     "0.09236600437082951`", "0.09`", "8.6`", "34.822913946624006`", 
     "0.707541305`", "0.703`", "1.0204081632653061`", "0.579`", 
     "2.557544757033248`", "1.4767183620357074`"},
    {"\<\"Belgium\"\>", "7233.228561414`", "0.17900000000000002`", 
     "0.04855764731224524`", "0.07`", "7.9`", "33.65730778904194`", 
     "0.718919208`", "0.613`", "0.970873786407767`", "0.584`", 
     "2.5974025974025974`", "0.8098129923752111`"},
    {"\<\"Canada\"\>", "20804.651599128`", "0.196`", "0.10135481428664642`", 
     "0.07`", "7.1`", "37.3557325051564`", "0.741359164`", "0.781`", 
     "0.8620689655172414`", "0.436`", "2.3255813953488373`", 
     "0.5004659786420894`"},
    {"\<\"Denmark\"\>", "3747.7924308`", "0.112`", "0.03943452940067237`", 
     "0.065`", "7.9`", "38.390866798694965`", "0.678112646`", "0.733`", 
     "1.3513513513513513`", "0.489`", "3.3222591362126246`", 
     "4.208904040608785`"},
    {"\<\"Finland\"\>", "3579.601717812`", "0.071`", "0.015532934162850403`", 
     "0.105`", "10.4`", "32.47316577751876`", "0.716063174`", "0.791`", "1.`",
      "0.513`", "2.8169014084507045`", "1.7751121891967614`"},
    {"\<\"France\"\>", "40417.937391997`", "0.088`", "0.07340645226949338`", 
     "0.077`", "9.4`", "32.412490209344455`", "0.723398834`", "0.69`", 
     "1.2195121951219512`", "0.62`", "2.6666666666666665`", 
     "1.5268506603654097`"},
    {"\<\"Germany\"\>", "60268.66674578`", "0.132`", "0.07885800370907958`", 
     "0.084`", "7.5`", "32.51201836379101`", "0.708518822`", "0.692`", 
     "1.2345679012345678`", "0.52`", "2.5`", "0.8162882018766895`"},
    {"\<\"Greece\"\>", "7749.624764`", "0.141`", "0.08047160772183161`", 
     "0.085`", "8.8`", "21.648273962803703`", "0.873351825`", "0.751`", 
     "0.9523809523809523`", "0.433`", "2.061855670103093`", 
     "0.3308419215002655`"},
    {"\<\"Iceland\"\>", "173.604205073`", "0.116`", "0.026521276204478725`", 
     "0.07`", "8.7`", "43.7143789046403`", "0.717741813`", "0.746`", 
     "1.3513513513513513`", "0.45`", "3.64963503649635`", 
     "0.23476129226317438`"},
    {"\<\"Ireland\"\>", "2309.218364864`", "0.168`", "0.019581675579937244`", 
     "0.115`", "7.`", "43.69400552811834`", "0.74485805`", "0.625`", 
     "0.8928571428571428`", "0.398`", "2.9154518950437316`", 
     "0.8324135752413923`"},
    {"\<\"Italy\"\>", "42626.923771872`", "0.057`", "0.021463518614864858`", 
     "0.065`", "9.1`", "31.089412107060912`", "0.794369457`", "0.85`", 
     "0.9523809523809523`", "0.508`", "2.5`", "0.9547976969024328`"},
    {"\<\"Japan\"\>", "92337.40933461`", "0.19`", "0.005397696753694667`", 
     "0.094`", "7.7`", "33.20164624600196`", "0.645120875`", "0.776`", 
     "1.0101010101010102`", "0.359`", "2.7247956403269757`", 
     "0.47853503724349317`"},
    {"\<\"Korea Rep\"\>", "42288.810314877`", "0.14800000000000002`", 
     "0.001698092576790638`", "0.107`", "8.3`", "21.63000077772844`", 
     "0.879291279`", "0.802`", "1.0101010101010102`", "0.28`", 
     "1.7889087656529514`", "0.08285208996645407`"},
    {"\<\"Luxembourg\"\>", "302.872240845`", "0.11`", "0.05900917428133145`", 
     "0.07`", "8.2`", "66.83015895919849`", "0.600900582`", "0.703`", 
     "0.970873786407767`", "0.477`", "2.7472527472527473`", 
     "4.524875609039063`"},
    {"\<\"Netherlands\"\>", "11109.305672205`", "0.149`", 
     "0.06969883582754223`", "0.07`", "7.3`", "36.699593298622176`", 
     "0.716845153`", "0.705`", "0.970873786407767`", "0.518`", 
     "2.5839793281653747`", "2.4749734032246398`"},
    {"\<\"New Zealand \"\>", "2399.6953253`", "0.20800000000000002`", 
     "0.051962982127496164`", "0.065`", "7.6`", "27.44931796363157`", 
     "0.823350711`", "0.761`", "0.8620689655172414`", "0.403`", 
     "2.463054187192118`", "0.3842326930192087`"},
    {"\<\"Norway \"\>", "3050.597728752`", "0.12200000000000001`", 
     "0.04018810071105467`", "0.055`", "7.4`", "41.03228649921283`", 
     "0.678512941`", "0.709`", "1.`", "0.533`", "3.2051282051282053`", 
     "2.9281587457466385`"},
    {"\<\"Portugal \"\>", "6888.6669687329995`", "0.03900000000000001`", 
     "0.04466277294714216`", "0.11`", "12.8`", "24.11918020629164`", 
     "0.8753592`", "0.725`", "0.9615384615384615`", "0.51`", 
     "1.976284584980237`", "1.864298688929334`"},
    {"\<\"Spain\"\>", "28838.931551884`", "0.121`", "0.03529713124262747`", 
     "0.1`", "9.`", "26.20402210950258`", "0.829928368`", "0.809`", 
     "0.9615384615384615`", "0.457`", "2.2075055187637966`", 
     "0.6475914530993421`"},
    {"\<\"Sweden\"\>", "6219.216877421`", "0.155`", "0.06595957103703862`", 
     "0.07`", "7.1`", "31.603818273902395`", "0.717738257`", "0.629`", 
     "1.1904761904761905`", "0.569`", "2.9154518950437316`", 
     "1.8235270228029983`"},
    {"\<\"Switzerland\"\>", "5200.36682275`", "0.128`", 
     "0.10102495471121042`", "0.104`", "8.`", "37.012004452835306`", 
     "0.636257542`", "0.871`", "1.0204081632653061`", "0.448`", 
     "3.2467532467532467`", "1.3124521005026142`"},
    {"\<\"UK\"\>", "40352.92231975`", "0.098`", "0.04554620121899976`", 
     "0.091`", "9.4`", "32.4620355775045`", "0.78182081`", "0.757`", 
     "1.1627906976744187`", "0.458`", "2.6881720430107525`", 
     "1.1156865799560258`"},
    {"\<\"USA\"\>", "183564.175624928`", "0.306`", "0.08716393365130651`", 
     "0.11`", "6.3`", "49.988239637505245`", "0.713532952`", "0.829`", 
     "1.2195121951219512`", "0.457`", "2.320185614849188`", 
     "0.188552405237486`"}
   },
   GridBoxAlignment->{
    "Columns" -> {{Left}}, "ColumnsIndexed" -> {}, "Rows" -> {{Baseline}}, 
     "RowsIndexed" -> {}},
   GridBoxSpacings->{"Columns" -> {
       Offset[0.27999999999999997`], {
        Offset[0.7]}, 
       Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
       Offset[0.2], {
        Offset[0.4]}, 
       Offset[0.2]}, "RowsIndexed" -> {}}],
  Function[BoxForm`e$, 
   TableForm[BoxForm`e$]]]], "Output",
 CellChangeTimes->{
  3.5634367712436895`*^9, 3.5635194821658435`*^9, {3.56352275973131*^9, 
   3.563522780734511*^9}, 3.5651956521592927`*^9, 3.565195697992173*^9, 
   3.5655076568803654`*^9, 3.5655201057950163`*^9, 3.5655918854028463`*^9, 
   3.5655924374321413`*^9, 3.5655926434945507`*^9, 3.5655943558663015`*^9, 
   3.565778061371024*^9, 3.5657803074375725`*^9, {3.565782178063322*^9, 
   3.565782205601999*^9}, {3.5824553167263002`*^9, 3.5824553430240774`*^9}, 
   3.582523394351296*^9, 3.582523686689464*^9, 3.5825241149857616`*^9, 
   3.5825244386929245`*^9, 3.5825248038277874`*^9, 3.582525079203785*^9, 
   3.582527897937599*^9, 3.582603655732004*^9, 3.5826061768397694`*^9, 
   3.582613425657318*^9, 3.5826135830688033`*^9, 3.5877920857933025`*^9, {
   3.587792561624467*^9, 3.5877925900816765`*^9}, 3.5877955510945544`*^9, 
   3.587805626259905*^9, 3.5878059498891706`*^9, 3.5878062135081234`*^9, {
   3.587806309214675*^9, 3.5878063281059723`*^9}, 3.5878065517858505`*^9, {
   3.587810950767889*^9, 3.587810973440575*^9}, 3.587813001983959*^9, 
   3.5878133639201746`*^9, 3.5878157691379533`*^9, 3.587815841679676*^9, 
   3.5878161324592767`*^9, 3.587816202506186*^9, 3.587880084992523*^9, 
   3.587880177574027*^9, 3.5878802174192305`*^9, 3.587982113486125*^9, 
   3.587982273913853*^9, 3.5879825375055075`*^9, 3.5879842718515415`*^9, 
   3.58798487078546*^9, 3.5879849642263703`*^9, 3.587985524934534*^9, 
   3.58798558801593*^9, 3.58798564442424*^9, 3.587985684630147*^9, 
   3.587985813916115*^9, 3.5879858567614255`*^9, 3.5879859072632713`*^9, 
   3.5879859609058523`*^9, {3.5879873200230513`*^9, 3.587987339664393*^9}, 
   3.5883313519455504`*^9, 3.5892906989076467`*^9, 3.5893511466402397`*^9, 
   3.5896311230763626`*^9, 3.590231428375292*^9, 3.5902951289897995`*^9, 
   3.590322250570653*^9, 3.5903223450270925`*^9, 3.5903224444474974`*^9, 
   3.590411167096513*^9, 3.59041172407864*^9, 3.5904117943154783`*^9, 
   3.5904118723963413`*^9, 3.590412064687724*^9, 3.5904122262033987`*^9, 
   3.5916136713077817`*^9, 3.591613760279809*^9, 3.5932542216205177`*^9, 
   3.593765095742299*^9, 3.593765529480217*^9, 3.5937677915840425`*^9, 
   3.5937678553366394`*^9, 3.593767933933593*^9, 3.593768081081028*^9, 
   3.593775679978208*^9, 3.5937779369340467`*^9, {3.5937788124852314`*^9, 
   3.593778834268474*^9}, 3.5938600897261496`*^9, 3.593868943066592*^9, 
   3.593869010022444*^9, 3.593924579352167*^9, 3.5939335563177176`*^9, 
   3.593935925687056*^9, 3.593937786458028*^9, 3.5942341393452954`*^9, 
   3.5942790512334776`*^9, 3.59427915528566*^9, 3.5942792516782293`*^9, {
   3.5945396317342253`*^9, 3.59453964793801*^9}, {3.5945486118418283`*^9, 
   3.5945486417024193`*^9}, {3.595133494583187*^9, 3.5951335185529146`*^9}}]
}, Open  ]]
}, Open  ]]
}, Open  ]]
},
WindowSize->{1350, 729},
WindowMargins->{{6, Automatic}, {Automatic, 38}},
PrintingCopies->1,
PrintingPageRange->{Automatic, Automatic},
FrontEndVersion->"7.0 for Microsoft Windows (64-bit) (November 10, 2008)",
StyleDefinitions->"Default.nb"
]
(* End of Notebook Content *)

(* Internal cache information *)
(*CellTagsOutline
CellTagsIndex->{}
*)
(*CellTagsIndex
CellTagsIndex->{}
*)
(*NotebookFileOutline
Notebook[{
Cell[CellGroupData[{
Cell[567, 22, 314, 6, 137, "Title"],
Cell[884, 30, 214, 4, 49, "Subtitle"],
Cell[CellGroupData[{
Cell[1123, 38, 102, 1, 71, "Section"],
Cell[1228, 41, 138, 1, 29, "Text"],
Cell[1369, 44, 1025, 28, 31, "Input"],
Cell[2397, 74, 131, 1, 29, "Text"],
Cell[2531, 77, 301, 8, 31, "Input"]
}, Open  ]],
Cell[CellGroupData[{
Cell[2869, 90, 94, 1, 71, "Section"],
Cell[CellGroupData[{
Cell[2988, 95, 104, 1, 27, "Subsubsection"],
Cell[CellGroupData[{
Cell[3117, 100, 1045, 25, 52, "Input"],
Cell[4165, 127, 2860, 42, 30, "Output"]
}, Open  ]]
}, Open  ]],
Cell[CellGroupData[{
Cell[7074, 175, 148, 2, 27, "Subsubsection"],
Cell[7225, 179, 2625, 40, 31, "Input"]
}, Open  ]]
}, Open  ]],
Cell[CellGroupData[{
Cell[9899, 225, 134, 2, 71, "Section"],
Cell[CellGroupData[{
Cell[10058, 231, 93, 1, 36, "Subsection"],
Cell[10154, 234, 1451, 23, 72, "Input"],
Cell[CellGroupData[{
Cell[11630, 261, 177, 4, 31, "Input"],
Cell[11810, 267, 2758, 38, 30, "Output"]
}, Open  ]],
Cell[14583, 308, 114, 1, 29, "Text"],
Cell[14700, 311, 229, 5, 31, "Input"],
Cell[14932, 318, 97, 1, 29, "Text"],
Cell[15032, 321, 1877, 41, 92, "Input"],
Cell[16912, 364, 457, 11, 31, "Input"],
Cell[CellGroupData[{
Cell[17394, 379, 133, 2, 27, "Subsubsection"],
Cell[17530, 383, 295, 4, 29, "Text"],
Cell[17828, 389, 1749, 32, 72, "Input"],
Cell[19580, 423, 176, 2, 29, "Text"],
Cell[19759, 427, 1078, 18, 72, "Input"],
Cell[20840, 447, 101, 1, 29, "Text"],
Cell[20944, 450, 1733, 28, 92, "Input"],
Cell[22680, 480, 844, 12, 29, "Text"],
Cell[23527, 494, 1792, 45, 52, "Input"],
Cell[25322, 541, 205, 3, 29, "Text"],
Cell[25530, 546, 2200, 39, 72, "Input"],
Cell[27733, 587, 325, 6, 29, "Text"],
Cell[28061, 595, 1941, 40, 112, "Input"],
Cell[30005, 637, 168, 2, 29, "Text"],
Cell[30176, 641, 1200, 25, 72, "Input"],
Cell[31379, 668, 116, 1, 29, "Text"],
Cell[31498, 671, 906, 16, 52, "Input"],
Cell[32407, 689, 366, 6, 29, "Text"],
Cell[32776, 697, 440, 7, 31, "Input"],
Cell[33219, 706, 116, 1, 29, "Text"],
Cell[33338, 709, 1033, 19, 92, "Input"],
Cell[34374, 730, 243, 8, 31, "Input"],
Cell[34620, 740, 174, 2, 29, "Text"],
Cell[34797, 744, 837, 15, 52, "Input"],
Cell[35637, 761, 312, 9, 31, "Input"],
Cell[35952, 772, 174, 4, 29, "Text"],
Cell[36129, 778, 1513, 27, 92, "Input"],
Cell[37645, 807, 1049, 30, 72, "Input"],
Cell[38697, 839, 120, 1, 29, "Text"],
Cell[38820, 842, 1102, 23, 72, "Input"],
Cell[39925, 867, 339, 6, 29, "Text"],
Cell[40267, 875, 1174, 24, 72, "Input"],
Cell[41444, 901, 227, 3, 29, "Text"],
Cell[41674, 906, 1507, 29, 72, "Input"],
Cell[43184, 937, 232, 3, 29, "Text"],
Cell[43419, 942, 2205, 47, 132, "Input"],
Cell[45627, 991, 121, 1, 29, "Text"],
Cell[45751, 994, 1041, 23, 72, "Input"],
Cell[46795, 1019, 2531, 54, 72, "Input"],
Cell[CellGroupData[{
Cell[49351, 1077, 230, 6, 31, "Input"],
Cell[49584, 1085, 1724, 28, 69, "Output"]
}, Open  ]],
Cell[51323, 1116, 2148, 58, 72, "Input"],
Cell[53474, 1176, 176, 2, 29, "Text"],
Cell[53653, 1180, 2056, 51, 69, "Input"],
Cell[CellGroupData[{
Cell[55734, 1235, 233, 6, 31, "Input"],
Cell[55970, 1243, 1886, 32, 69, "Output"]
}, Open  ]],
Cell[CellGroupData[{
Cell[57893, 1280, 299, 8, 31, "Input"],
Cell[58195, 1290, 1755, 30, 69, "Output"]
}, Open  ]]
}, Open  ]]
}, Open  ]]
}, Open  ]],
Cell[CellGroupData[{
Cell[60023, 1328, 165, 2, 71, "Section"],
Cell[60191, 1332, 213, 3, 29, "Text"],
Cell[60407, 1337, 1197, 26, 49, "Input"],
Cell[CellGroupData[{
Cell[61629, 1367, 165, 5, 31, "Input"],
Cell[61797, 1374, 3493, 53, 50, "Output"]
}, Open  ]]
}, Open  ]],
Cell[CellGroupData[{
Cell[65339, 1433, 207, 3, 71, "Section"],
Cell[65549, 1438, 1275, 20, 31, "Input"],
Cell[CellGroupData[{
Cell[66849, 1462, 2218, 54, 52, "Input"],
Cell[69070, 1518, 9144, 147, 390, "Output"]
}, Open  ]]
}, Open  ]]
}, Open  ]]
}
]
*)

(* End of internal cache information *)
